@@ -6,6 +6,7 @@ import (
 	"net/http"
 	"os"
 	"path"
+	"regexp"
 	"strings"
 
 	"github.com/pkg/errors"
@@ -16,7 +17,12 @@ import (
 	storkutil "isc.org/stork/util"
 )
 
-var _ App = (*KeaApp)(nil)
+var (
+	_ App = (*KeaApp)(nil)
+
+	// Pattern for detecting Kea Control Agent process.
+	keaCtrlAgentPattern = regexp.MustCompile(`(.*?)kea-ctrl-agent\s+.*-c\s+(\S+)`)
+)
 
 // It holds common and Kea specific runtime information.
 type KeaApp struct {
@@ -56,7 +62,7 @@ func (ka *KeaApp) sendCommand(command *keactrl.Command, responses interface{}) e
 // Sends a serialized command to Kea and returns a serialized response.
 func (ka *KeaApp) sendCommandRaw(command []byte) ([]byte, error) {
 	var accessPoint *AccessPoint
-	for _, ap := range ka.BaseApp.AccessPoints {
+	for _, ap := range ka.AccessPoints {
 		if ap.Type == AccessPointControl {
 			accessPoint = &ap
 			break
@@ -151,7 +157,7 @@ func (ka *KeaApp) DetectAllowedLogs() ([]string, error) {
 		return nil, err
 	}
 
-	ap := ka.BaseApp.AccessPoints[0]
+	ap := ka.AccessPoints[0]
 
 	// There should be exactly one response received because we sent the command
 	// to only one daemon.
@@ -209,6 +215,11 @@ func (ka *KeaApp) DetectAllowedLogs() ([]string, error) {
 // It does nothing as it applies to DNS servers only.
 func (ka *KeaApp) StopZoneInventory() {}
 
+// Always returns nil. It is implemented to satisfy the App interface.
+func (ka *KeaApp) GetZoneInventory() *zoneInventory {
+	return nil
+}
+
 // Reads the Kea configuration file, resolves the includes, and parses the content.
 func readKeaConfig(path string) (*keaconfig.Config, error) {
 	text, err := storkutil.ReadFileWithIncludes(path)
@@ -227,32 +238,42 @@ func readKeaConfig(path string) (*keaconfig.Config, error) {
 }
 
 // Detect the Kea application by parsing the Kea CA process command line.
-// The match is a slice of: the full command line, the directory path of the
-// Kea CA executable, and the path to the Kea CA configuration file.
-// The cwd is a path to the current working directory used to resolve relative
-// paths in the Kea CA configuration file.
-// The HTTP client cloner is used to create a new HTTP client instance for the
-// detected Kea app.
-// Returns the Kea app instance or an error if the Kea CA configuration is
-// invalid.
+// This function parses the command line of the specified process. It looks
+// for the Kea CA configuration file path in the command line. If the path is
+// relative, it is resolved against the current working directory of the process.
 //
-// This function reads the Kea CA configuration file and extracts its HTTP
-// host, port, TLS configuration, basic authentication credentials, and list
-// of configured daemons. The returned instance lacks information about the
-// active daemons. It must be detected separately.
+// It reads the Kea CA configuration file and extracts its HTTP host, port,
+// TLS configuration, basic authentication credentials, and list of configured
+// daemons. The returned instance lacks information about the active daemons.
+// It must be detected separately.
 //
-// The Kea application instance has internal HTTP client intended to be used
-// for communication with this Kea CA. The client inherits the the general
-// HTTP client configuration from the Stork agent configuration and
-// additionally sets the basic authentication credentials if they are provided
-// in the Kea CA configuration. It picks the first credentials with the user
-// name "stork" or starting with "stork." If there are no such credentials, it
-// picks the first one. See @readClientCredentials for details.
-// The user name of the selected credentials is used as a key of the
-// application's access point.
-func detectKeaApp(match []string, cwd string, httpClientConfig HTTPClientConfig) (*KeaApp, error) {
+// The specified httpClientConfig is used to create a new HTTP client instance
+// for the detected Kea app. The client inherits the the general HTTP client
+// configuration from the Stork agent configuration and additionally sets the
+// basic authentication credentials if they are provided in the Kea CA
+// configuration. It picks the first credentials with the user name "stork" or
+// starting with "stork." If there are no such credentials, it picks the first
+// one. See @readClientCredentials for details.
+//
+// It returns the Kea app instance or an error if the Kea is not recognized or
+// any error occurs.
+func detectKeaApp(p supportedProcess, httpClientConfig HTTPClientConfig) (App, error) {
+	cmdline, err := p.getCmdline()
+	if err != nil {
+		return nil, err
+	}
+	cwd, err := p.getCwd()
+	if err != nil {
+		log.WithError(err).Warn("Cannot get Kea process current working directory")
+	}
+
+	match := keaCtrlAgentPattern.FindStringSubmatch(cmdline)
+	if match == nil {
+		return nil, errors.Errorf("problem parsing Kea command line: %s", cmdline)
+	}
+
 	if len(match) < 3 {
-		return nil, errors.Errorf("problem parsing Kea cmdline: %s", match[0])
+		return nil, errors.Errorf("problem parsing Kea command line: %s", match[0])
 	}
 	keaConfPath := match[2]
 
