@@ -305,9 +305,20 @@ func (sm *appMonitor) detectApps(storkAgent *StorkAgent) {
 				}
 			}
 		case pdnsProcName:
-			// PowerDNS server.
-			if detectedApp, err = detectPowerDNSApp(p, sm.pdnsConfigParser); err != nil {
-				log.WithError(err).Warn("Failed to detect PowerDNS server app")
+			// PowerDNS server configuration location detection.
+			configPath, err := detectPowerDNSAppConfigPath(p, sm.commander, storkAgent.ExplicitPowerDNSConfigPath)
+			if err != nil {
+				log.WithError(err).Warn("Failed to detect PowerDNS server config path")
+				continue
+			}
+			log.WithFields(log.Fields{
+				"path": *configPath,
+			}).Debug("PowerDNS server config path detected")
+
+			// Parse and interpret the PowerDNS server configuration.
+			detectedApp, err = configurePowerDNSApp(*configPath, sm.pdnsConfigParser)
+			if err != nil {
+				log.WithError(err).Warn("PowerDNS server configuration is invalid")
 				continue
 			}
 			for _, app := range sm.apps {
