@@ -60,7 +60,7 @@ func TestGetApps(t *testing.T) {
 	hm := NewHookManager()
 	bind9StatsClient := NewBind9StatsClient()
 	httpClientConfig := HTTPClientConfig{}
-	sa := NewStorkAgent("foo", 42, am, bind9StatsClient, httpClientConfig, hm, "")
+	sa := NewStorkAgent("foo", 42, am, bind9StatsClient, httpClientConfig, hm, "", "")
 	am.Start(sa)
 	apps := am.GetApps()
 	require.Len(t, apps, 0)
@@ -238,7 +238,7 @@ func TestDetectApps(t *testing.T) {
 
 	pdnsProcess := NewMockSupportedProcess(ctrl)
 	pdnsProcess.EXPECT().getName().AnyTimes().Return("pdns_server", nil)
-	pdnsProcess.EXPECT().getCmdline().AnyTimes().Return("pdns_server -c /etc/powerdns/pdns.conf", nil)
+	pdnsProcess.EXPECT().getCmdline().AnyTimes().Return("pdns_server --config-dir=/etc/powerdns", nil)
 	pdnsProcess.EXPECT().getCwd().AnyTimes().Return("/etc", nil)
 	pdnsProcess.EXPECT().getPid().AnyTimes().Return(int32(7890))
 	pdnsProcess.EXPECT().getParentPid().AnyTimes().Return(int32(8901), nil)
@@ -274,7 +274,7 @@ func TestDetectApps(t *testing.T) {
 	hm := NewHookManager()
 	bind9StatsClient := NewBind9StatsClient()
 	httpConfig := HTTPClientConfig{}
-	sa := NewStorkAgent("foo", 42, am, bind9StatsClient, httpConfig, hm, "")
+	sa := NewStorkAgent("foo", 42, am, bind9StatsClient, httpConfig, hm, "", "")
 
 	// Create fake app for which the zone inventory should be stopped
 	// when new apps are detected.
@@ -372,7 +372,7 @@ func TestDetectAppsConfigNoStatistics(t *testing.T) {
 	hm := NewHookManager()
 	bind9StatsClient := NewBind9StatsClient()
 	httpConfig := HTTPClientConfig{}
-	sa := NewStorkAgent("foo", 42, am, bind9StatsClient, httpConfig, hm, "")
+	sa := NewStorkAgent("foo", 42, am, bind9StatsClient, httpConfig, hm, "", "")
 
 	// Create fake app to test that the monitor stops zone inventory
 	// when new apps are detected.
@@ -428,7 +428,7 @@ func TestDetectAppsContinueOnNotAvailableCommandLine(t *testing.T) {
 	hm := NewHookManager()
 	bind9StatsClient := NewBind9StatsClient()
 	httpConfig := HTTPClientConfig{}
-	sa := NewStorkAgent("foo", 42, am, bind9StatsClient, httpConfig, hm, "")
+	sa := NewStorkAgent("foo", 42, am, bind9StatsClient, httpConfig, hm, "", "")
 
 	// Act
 	am.detectApps(sa)
@@ -477,7 +477,7 @@ func TestDetectAppsSkipOnNotAvailableCwd(t *testing.T) {
 	hm := NewHookManager()
 	bind9StatsClient := NewBind9StatsClient()
 	httpConfig := HTTPClientConfig{}
-	sa := NewStorkAgent("foo", 42, am, bind9StatsClient, httpConfig, hm, "")
+	sa := NewStorkAgent("foo", 42, am, bind9StatsClient, httpConfig, hm, "", "")
 
 	// Act
 	am.detectApps(sa)
@@ -515,7 +515,7 @@ func TestDetectAppsNoAppDetectedWarning(t *testing.T) {
 	hm := NewHookManager()
 	bind9StatsClient := NewBind9StatsClient()
 	httpConfig := HTTPClientConfig{}
-	sa := NewStorkAgent("foo", 42, am, bind9StatsClient, httpConfig, hm, "")
+	sa := NewStorkAgent("foo", 42, am, bind9StatsClient, httpConfig, hm, "", "")
 
 	// Act
 	am.detectApps(sa)
@@ -545,7 +545,7 @@ func TestDetectAllowedLogsKeaUnreachable(t *testing.T) {
 	})
 
 	hm := NewHookManager()
-	sa := NewStorkAgent("foo", 42, am, bind9StatsClient, httpConfig, hm, "")
+	sa := NewStorkAgent("foo", 42, am, bind9StatsClient, httpConfig, hm, "", "")
 
 	require.NotPanics(t, func() { am.detectAllowedLogs(sa) })
 }
@@ -608,49 +608,6 @@ func TestDetectBind9AppRelativePath(t *testing.T) {
 	require.Equal(t, app.GetBaseApp().Type, AppTypeBind9)
 }
 
-// Check PowerDNS app detection when its conf file is absolute path.
-func TestDetectPowerDNSAppAbsPath(t *testing.T) {
-	// check BIND 9 app detection
-	ctrl := gomock.NewController(t)
-	defer ctrl.Finish()
-
-	parser := NewMockPDNSConfigParser(ctrl)
-	parser.EXPECT().ParseFile("/etc/pdns.conf").AnyTimes().DoAndReturn(func(configPath string) (*pdnsconfig.Config, error) {
-		return pdnsconfig.NewParser().Parse(strings.NewReader(defaultPDNSConfig))
-	})
-	process := NewMockSupportedProcess(ctrl)
-	process.EXPECT().getCmdline().Return("/dir/pdns_server --config-dir=/etc", nil)
-	process.EXPECT().getCwd().Return("", nil)
-	app, err := detectPowerDNSApp(process, parser)
-	require.NoError(t, err)
-	require.NotNil(t, app)
-	require.Equal(t, app.GetBaseApp().Type, AppTypePowerDNS)
-	require.Len(t, app.GetBaseApp().AccessPoints, 1)
-	point := app.GetBaseApp().AccessPoints[0]
-	require.Equal(t, AccessPointControl, point.Type)
-	require.Equal(t, "127.0.0.1", point.Address)
-	require.EqualValues(t, 8081, point.Port)
-	require.NotEmpty(t, point.Key)
-}
-
-// Check PowerDNS app detection when its conf file is relative to CWD of its process.
-func TestDetectPowerDNSAppRelativePath(t *testing.T) {
-	ctrl := gomock.NewController(t)
-	defer ctrl.Finish()
-
-	parser := NewMockPDNSConfigParser(ctrl)
-	parser.EXPECT().ParseFile("/etc/powerdns/pdns.conf").AnyTimes().DoAndReturn(func(configPath string) (*pdnsconfig.Config, error) {
-		return pdnsconfig.NewParser().Parse(strings.NewReader(defaultPDNSConfig))
-	})
-	process := NewMockSupportedProcess(ctrl)
-	process.EXPECT().getCmdline().Return("/dir/pdns_server --config-name=pdns.conf", nil)
-	process.EXPECT().getCwd().Return("/etc", nil)
-	app, err := detectPowerDNSApp(process, parser)
-	require.NoError(t, err)
-	require.NotNil(t, app)
-	require.Equal(t, app.GetBaseApp().Type, AppTypePowerDNS)
-}
-
 // Creates a basic Kea configuration file.
 // Caller is responsible for remove the file.
 func makeKeaConfFile() (string, func()) {
