@@ -49,6 +49,7 @@ type PromBind9ExporterStats struct {
 	IncomingQueries  map[string]float64
 	IncomingRequests map[string]float64
 	NsStats          map[string]float64
+	ZoneStats        map[string]float64
 	TaskMgr          map[string]float64
 	TrafficStats     map[string]PromBind9TrafficStats
 	Views            map[string]PromBind9ViewStats
@@ -355,21 +356,46 @@ func NewPromBind9Exporter(host string, port int, appMonitor AppMonitor, httpClie
 		"Total number of available worker threads.",
 		nil, nil)
 
-	// zone_transfer_failure_total
-	serverStatsDesc["XfrFail"] = prometheus.NewDesc(
-		prometheus.BuildFQName(namespace, "", "zone_transfer_failure_total"),
-		"Number of failed zone transfers.",
-		nil, nil)
 	// zone_transfer_rejected_total
 	serverStatsDesc["XfrRej"] = prometheus.NewDesc(
 		prometheus.BuildFQName(namespace, "", "zone_transfer_rejected_total"),
 		"Number of rejected zone transfers.",
 		nil, nil)
+	// zone_transfer_requests_done
+	serverStatsDesc["XfrReqDone"] = prometheus.NewDesc(
+		prometheus.BuildFQName(namespace, "", "zone_transfer_requests_done"),
+		"Number of requested and completed zone transfers.",
+		nil, nil)
 	// zone_transfer_success_total
 	serverStatsDesc["XfrSuccess"] = prometheus.NewDesc(
 		prometheus.BuildFQName(namespace, "", "zone_transfer_success_total"),
 		"Number of successful zone transfers.",
 		nil, nil)
+	// zone_transfer_failure_total
+	serverStatsDesc["XfrFail"] = prometheus.NewDesc(
+		prometheus.BuildFQName(namespace, "", "zone_transfer_failure_total"),
+		"Number of failed zone transfers.",
+		nil, nil)
+	// zone_transfer_requests_ipv4
+	serverStatsDesc["AXFRReqv4"] = prometheus.NewDesc(
+		prometheus.BuildFQName(namespace, "", "zone_transfer_requests_ipv4"),
+		"Number of requested IPv4 zone transfers.",
+		nil, nil)
+	// zone_transfer_requests_ipv6
+	serverStatsDesc["AXFRReqv6"] = prometheus.NewDesc(
+		prometheus.BuildFQName(namespace, "", "zone_transfer_requests_ipv6"),
+		"Number of requested IPv6 zone transfers.",
+		nil, nil)
+	// zone_transfer_incremental_requests_ipv4
+	serverStatsDesc["IXFRReqv4"] = prometheus.NewDesc(
+		prometheus.BuildFQName(namespace, "", "zone_transfer_incremental_requests_ipv4"),
+		"Number of requested IPv4 incremental zone transfers.",
+		nil, nil)
+	// zone_transfer_incremental_requests_ipv6
+	serverStatsDesc["IXFRReqv6"] = prometheus.NewDesc(
+		prometheus.BuildFQName(namespace, "", "zone_transfer_incremental_requests_ipv6"),
+		"Number of requested IPv6 incremental zone transfers.",
+		nil, nil)
 
 	pbe.serverStatsDesc = serverStatsDesc
 	pbe.trafficStatsDesc = trafficStatsDesc
@@ -569,6 +595,29 @@ func (pbe *PromBind9Exporter) Collect(ch chan<- prometheus.Metric) {
 		return
 	}
 
+	// Collect basic metrics (uptime, up status, time metrics)
+	pbe.collectBasicMetrics(ch)
+
+	if err != nil {
+		log.WithError(err).Error("Some errors were encountered while collecting stats from BIND 9")
+	}
+
+	// if not up or error encountered, don't bother collecting.
+	if pbe.up == 0 || err != nil {
+		return
+	}
+
+	// Collect all other metrics
+	pbe.collectQueryMetrics(ch)
+	pbe.collectResponseMetrics(ch)
+	pbe.collectTaskMetrics(ch)
+	pbe.collectZoneTransferMetrics(ch)
+	pbe.collectTrafficMetrics(ch)
+	pbe.collectViewMetrics(ch)
+}
+
+// Collects basic server metrics like uptime, up status, and time metrics.
+func (pbe *PromBind9Exporter) collectBasicMetrics(ch chan<- prometheus.Metric) {
 	// uptime_seconds (Uptime of the Stork Agent)
 	ch <- prometheus.MustNewConstMetric(
 		pbe.serverStatsDesc["uptime-seconds"],
@@ -578,22 +627,16 @@ func (pbe *PromBind9Exporter) Collect(ch chan<- prometheus.Metric) {
 	// up
 	ch <- prometheus.MustNewConstMetric(pbe.serverStatsDesc["up"], prometheus.GaugeValue, float64(pbe.up))
 
-	if err != nil {
-		log.Errorf("Some errors were encountered while collecting stats from BIND 9: %+v", err)
-	}
-
-	// if not up or error encountered, don't bother collecting.
-	if pbe.up == 0 || err != nil {
-		return
-	}
-
 	// boot_time_seconds
 	pbe.collectTime(ch, "boot-time", pbe.stats.BootTime)
 	// config_time_seconds
 	pbe.collectTime(ch, "config-time", pbe.stats.ConfigTime)
 	// current_time_seconds
 	pbe.collectTime(ch, "current-time", pbe.stats.CurrentTime)
+}
 
+// Collects query-related statistics.
+func (pbe *PromBind9Exporter) collectQueryMetrics(ch chan<- prometheus.Metric) {
 	// incoming_queries_total
 	for label, value := range pbe.stats.IncomingQueries {
 		ch <- prometheus.MustNewConstMetric(
@@ -643,9 +686,6 @@ func (pbe *PromBind9Exporter) Collect(ch chan<- prometheus.Metric) {
 		pbe.serverStatsDesc["QryDuplicate"],
 		prometheus.CounterValue, value)
 	// query_errors_total
-	trimQryPrefix := func(name string) string {
-		return strings.TrimPrefix(name, "Qry")
-	}
 	qryErrors := []string{"QryDropped", "QryFailure"}
 	for _, label := range qryErrors {
 		value, ok = pbe.stats.NsStats[label]
@@ -656,7 +696,7 @@ func (pbe *PromBind9Exporter) Collect(ch chan<- prometheus.Metric) {
 		ch <- prometheus.MustNewConstMetric(
 			pbe.serverStatsDesc["QryErrors"],
 			prometheus.CounterValue,
-			value, trimQryPrefix(label))
+			value, strings.TrimPrefix(label, "Qry"))
 	}
 	// query_recursion_total
 	value, ok = pbe.stats.NsStats["QryRecursion"]
@@ -673,7 +713,10 @@ func (pbe *PromBind9Exporter) Collect(ch chan<- prometheus.Metric) {
 			pbe.serverStatsDesc["RecursClients"],
 			prometheus.CounterValue, value)
 	}
+}
 
+// Collects server response statistics.
+func (pbe *PromBind9Exporter) collectResponseMetrics(ch chan<- prometheus.Metric) {
 	// responses_total
 	serverResponses := []string{
 		"QrySuccess",
@@ -684,7 +727,7 @@ func (pbe *PromBind9Exporter) Collect(ch chan<- prometheus.Metric) {
 		"QryNXDOMAIN",
 	}
 	for _, label := range serverResponses {
-		value, ok = pbe.stats.NsStats[label]
+		value, ok := pbe.stats.NsStats[label]
 		if !ok {
 			value = 0
 		}
@@ -692,14 +735,17 @@ func (pbe *PromBind9Exporter) Collect(ch chan<- prometheus.Metric) {
 		ch <- prometheus.MustNewConstMetric(
 			pbe.serverStatsDesc["ServerResponses"],
 			prometheus.CounterValue,
-			value, trimQryPrefix(label))
+			value, strings.TrimPrefix(label, "Qry"))
 	}
+}
 
+// Collects task manager statistics.
+func (pbe *PromBind9Exporter) collectTaskMetrics(ch chan<- prometheus.Metric) {
 	// tasks_running
 	// worker_threads
 	taskMgrStats := []string{"tasks-running", "worker-threads"}
 	for _, label := range taskMgrStats {
-		value, ok = pbe.stats.TaskMgr[label]
+		value, ok := pbe.stats.TaskMgr[label]
 		if !ok {
 			value = 0
 		}
@@ -708,13 +754,15 @@ func (pbe *PromBind9Exporter) Collect(ch chan<- prometheus.Metric) {
 			pbe.serverStatsDesc[label],
 			prometheus.GaugeValue, value)
 	}
+}
 
-	// zone_transfer_failure_total
+// Collects zone transfer statistics.
+func (pbe *PromBind9Exporter) collectZoneTransferMetrics(ch chan<- prometheus.Metric) {
 	// zone_transfer_rejected_total
-	// zone_transfer_success_total
-	xfrStats := []string{"XfrFail", "XfrRej", "XfrSuccess"}
-	for _, label := range xfrStats {
-		value, ok = pbe.stats.NsStats[label]
+	// zone_transfer_requests_done
+	nsXfrStats := []string{"XfrReqDone", "XfrRej"}
+	for _, label := range nsXfrStats {
+		value, ok := pbe.stats.NsStats[label]
 		if !ok {
 			value = 0
 		}
@@ -723,6 +771,26 @@ func (pbe *PromBind9Exporter) Collect(ch chan<- prometheus.Metric) {
 			prometheus.CounterValue, value)
 	}
 
+	// zone_transfer_success_total
+	// zone_transfer_failure_total
+	// zone_transfer_requests_ipv4
+	// zone_transfer_requests_ipv6
+	// zone_transfer_incremental_requests_ipv4
+	// zone_transfer_incremental_requests_ipv6
+	zoneXfrStats := []string{"XfrSuccess", "XfrFail", "AXFRReqv4", "AXFRReqv6", "IXFRReqv4", "IXFRReqv6"}
+	for _, label := range zoneXfrStats {
+		value, ok := pbe.stats.ZoneStats[label]
+		if !ok {
+			value = 0
+		}
+		ch <- prometheus.MustNewConstMetric(
+			pbe.serverStatsDesc[label],
+			prometheus.CounterValue, value)
+	}
+}
+
+// Collects traffic statistics.
+func (pbe *PromBind9Exporter) collectTrafficMetrics(ch chan<- prometheus.Metric) {
 	// Traffic metrics.
 
 	// traffic_incoming_requests_udp4_size_{bucket,count,sum}
@@ -742,7 +810,10 @@ func (pbe *PromBind9Exporter) Collect(ch chan<- prometheus.Metric) {
 				count, sum, buckets)
 		}
 	}
+}
 
+// Collects view-specific statistics.
+func (pbe *PromBind9Exporter) collectViewMetrics(ch chan<- prometheus.Metric) {
 	// View metrics.
 	for view, viewStats := range pbe.stats.Views {
 		// resolver_cache_rrsets
@@ -914,21 +985,21 @@ func (pbe *PromBind9Exporter) scrapeTimeStats(statMap map[string]interface{}) (e
 	timeStr = getStat(statMap, "boot-time").(string)
 	timeVal, err = time.Parse(time.RFC3339, timeStr)
 	if err != nil {
-		return pkgerrors.Errorf("problem parsing time %+s: %+v", timeStr, err)
+		return pkgerrors.Wrapf(err, "problem parsing time %+s", timeStr)
 	}
 	pbe.stats.BootTime = timeVal
 	// config_time_seconds
 	timeStr = getStat(statMap, "config-time").(string)
 	timeVal, err = time.Parse(time.RFC3339, timeStr)
 	if err != nil {
-		return pkgerrors.Errorf("problem parsing time %+s: %+v", timeStr, err)
+		return pkgerrors.Wrapf(err, "problem parsing time %+s", timeStr)
 	}
 	pbe.stats.ConfigTime = timeVal
 	// current_time_seconds
 	timeStr = getStat(statMap, "current-time").(string)
 	timeVal, err = time.Parse(time.RFC3339, timeStr)
 	if err != nil {
-		return pkgerrors.Errorf("problem parsing time %+s: %+v", timeStr, err)
+		return pkgerrors.Wrapf(err, "problem parsing time %+s", timeStr)
 	}
 	pbe.stats.CurrentTime = timeVal
 
@@ -1096,31 +1167,41 @@ func (pbe *PromBind9Exporter) setDaemonStats(stats map[string]any) (ret error) {
 	// incoming_queries_total
 	pbe.stats.IncomingQueries, err = pbe.scrapeServerStat(stats, "qtypes")
 	if err != nil {
-		return pkgerrors.Errorf("problem parsing 'qtypes': %+v", err)
+		return pkgerrors.Wrapf(err, "problem parsing 'qtypes'")
 	}
 	// incoming_requests_total
 	pbe.stats.IncomingRequests, err = pbe.scrapeServerStat(stats, "opcodes")
 	if err != nil {
-		return pkgerrors.Errorf("problem parsing 'opcodes': %+v", err)
+		return pkgerrors.Wrapf(err, "problem parsing 'opcodes'")
 	}
 
 	// query_duplicates_total
 	// query_errors_total
 	// query_recursion_total
 	// recursive_clients
-	// zone_transfer_failure_total
 	// zone_transfer_rejected_total
-	// zone_transfer_success_total
+	// zone_transfer_requests_done
 	pbe.stats.NsStats, err = pbe.scrapeServerStat(stats, "nsstats")
 	if err != nil {
-		return pkgerrors.Errorf("problem parsing 'nsstats': %+v", err)
+		return pkgerrors.Wrapf(err, "problem parsing 'nsstats'")
+	}
+
+	// zone_transfer_success_total
+	// zone_transfer_failure_total
+	// zone_transfer_requests_ipv4
+	// zone_transfer_requests_ipv6
+	// zone_transfer_incremental_requests_ipv4
+	// zone_transfer_incremental_requests_ipv6
+	pbe.stats.ZoneStats, err = pbe.scrapeServerStat(stats, "zonestats")
+	if err != nil {
+		return pkgerrors.Wrapf(err, "problem parsing 'zonestats'")
 	}
 
 	// tasks_running
 	// worker_threads
 	pbe.stats.TaskMgr, err = pbe.scrapeServerStat(stats, "taskmgr")
 	if err != nil {
-		return pkgerrors.Errorf("problem parsing 'taskmgr': %+v", err)
+		return pkgerrors.Wrapf(err, "problem parsing 'taskmgr'")
 	}
 
 	// Parse traffic stats.
@@ -1215,7 +1296,7 @@ APP_LOOP:
 		err = pbe.setDaemonStats(stats)
 		if err != nil {
 			lastErr = err
-			log.Errorf("Cannot get stat from daemon: %+v", err)
+			log.WithError(err).Error("Cannot get stat from daemon")
 			continue
 		}
 
