@@ -7,6 +7,7 @@ import (
 	"testing"
 	"time"
 
+	"github.com/prometheus/client_golang/prometheus"
 	"github.com/stretchr/testify/require"
 	"gopkg.in/h2non/gock.v1"
 )
@@ -30,6 +31,7 @@ func (fam *PromFakeBind9AppMonitor) GetApps() []App {
 	})
 	ba := &Bind9App{
 		BaseApp: BaseApp{
+			Pid:          1234,
 			Type:         AppTypeBind9,
 			AccessPoints: accessPoints,
 		},
@@ -59,7 +61,7 @@ func TestNewPromBind9ExporterBasic(t *testing.T) {
 	require.Equal(t, 42, pbe.Port)
 	require.NotNil(t, pbe.HTTPClient)
 	require.NotNil(t, pbe.HTTPServer)
-	require.Len(t, pbe.serverStatsDesc, 20)
+	require.Len(t, pbe.serverStatsDesc, 25)
 	require.Len(t, pbe.viewStatsDesc, 18)
 }
 
@@ -281,10 +283,66 @@ func TestPromBind9ExporterStart(t *testing.T) {
 	require.Zero(t, buckets[math.Inf(0)])
 	require.Nil(t, err)
 
-	// zone_transfer_failure_total
-	require.EqualValues(t, 2.0, pbe.stats.NsStats["XfrFail"])
 	// zone_transfer_rejected_total
 	require.EqualValues(t, 11.0, pbe.stats.NsStats["XfrRej"])
+	// zone_transfer_requests_done
+	require.EqualValues(t, 37.0, pbe.stats.NsStats["XfrReqDone"])
 	// zone_transfer_success_total
-	require.EqualValues(t, 22.0, pbe.stats.NsStats["XfrSuccess"])
+	require.EqualValues(t, 22.0, pbe.stats.ZoneStats["XfrSuccess"])
+	// zone_transfer_failure_total
+	require.EqualValues(t, 4.0, pbe.stats.ZoneStats["XfrFail"])
+	// zone_transfer_requests_ipv4
+	require.EqualValues(t, 6.0, pbe.stats.ZoneStats["AXFRReqv4"])
+	// zone_transfer_requests_ipv6
+	require.EqualValues(t, 10.0, pbe.stats.ZoneStats["AXFRReqv6"])
+	// zone_transfer_incremental_requests_ipv4
+	require.EqualValues(t, 5.0, pbe.stats.ZoneStats["IXFRReqv4"])
+	// zone_transfer_incremental_requests_ipv6
+	require.EqualValues(t, 4.0, pbe.stats.ZoneStats["IXFRReqv6"])
+}
+
+// Check that stats can be exported to Prometheus format and that the
+// number of returned metrics is correct.
+func TestPromBind9ExporterCollect(t *testing.T) {
+	defer gock.Off()
+	gock.New("http://localhost:1234/").
+		Get("json/(.+)/server").
+		AddMatcher(func(r1 *http.Request, r2 *gock.Request) (bool, error) {
+			// Require empty body
+			return r1.Body == nil, nil
+		}).
+		Persist().
+		Reply(200).
+		AddHeader("Content-Type", "application/json").
+		BodyString(string(bind9PromServerStats))
+
+	gock.New("http://localhost:1234/").
+		Get("json/(.+)/traffic").
+		AddMatcher(func(r1 *http.Request, r2 *gock.Request) (bool, error) {
+			// Require empty body
+			return r1.Body == nil, nil
+		}).
+		Persist().
+		Reply(200).
+		AddHeader("Content-Type", "application/json").
+		BodyString(string(bind9PromTrafficStats))
+
+	fam := &PromFakeBind9AppMonitor{}
+	httpClient := NewBind9StatsClient()
+	pbe := NewPromBind9Exporter("localhost", 1234, fam, httpClient)
+	defer pbe.Shutdown()
+
+	gock.InterceptClient(pbe.HTTPClient.innerClient.GetClient())
+
+	// start exporter
+	pbe.Start()
+	require.EqualValues(t, 1, pbe.up)
+
+	// Collect stats into the channel.
+	ch := make(chan prometheus.Metric, 1000)
+	defer close(ch)
+	pbe.Collect(ch)
+
+	// Make sure that the number of returned metrics is correct.
+	require.Len(t, ch, 71)
 }
