@@ -4,7 +4,6 @@ import (
 	_ "embed"
 	"encoding/json"
 	"testing"
-	"time"
 
 	"github.com/pkg/errors"
 	"github.com/prometheus/client_golang/prometheus"
@@ -55,17 +54,16 @@ func newFakeMonitorWithDefaultsDHCPv6Only() *FakeAppMonitor {
 // Check creating PromKeaExporter, check if prometheus stats are set up.
 func TestNewPromKeaExporterBasic(t *testing.T) {
 	fam := newFakeMonitorWithDefaults()
-	pke := NewPromKeaExporter("foo", 42, 24*time.Millisecond, true, fam)
+	pke := NewPromKeaExporter("foo", 42, true, fam)
 	defer pke.Shutdown()
 
 	require.NotNil(t, pke.HTTPServer)
 
 	require.Equal(t, "foo", pke.Host)
 	require.Equal(t, 42, pke.Port)
-	require.Equal(t, 24*time.Millisecond, pke.Interval)
 	require.Len(t, pke.PktStatsMap, 31)
-	require.Len(t, pke.Adr4StatsMap, 6)
-	require.Len(t, pke.Adr6StatsMap, 9)
+	require.Len(t, pke.Addr4StatsMap, 12)
+	require.Len(t, pke.Addr6StatsMap, 19)
 }
 
 // Check starting PromKeaExporter and collecting stats.
@@ -106,42 +104,50 @@ func TestPromKeaExporterStart(t *testing.T) {
 
 	fam := newFakeMonitorWithDefaultsDHCPv4Only()
 
-	pke := NewPromKeaExporter("foo", 1234, 1*time.Millisecond, true, fam)
+	pke := NewPromKeaExporter("foo", 1234, true, fam)
 	defer pke.Shutdown()
 
 	gock.InterceptClient(fam.HTTPClient.client)
 
-	// start exporter
+	// Start exporter.
 	pke.Start()
-	require.NotNil(t, pke.Ticker)
 
-	// wait for collecting is invoked at least once
-	require.Eventually(t, func() bool {
-		metric, _ := pke.Adr4StatsMap["assigned-addresses"].GetMetricWith(
-			prometheus.Labels{
-				"subnet":    "7",
-				"subnet_id": "7",
-				"prefix":    "",
-			},
-		)
-		return testutil.ToFloat64(metric) == 13.0
-	}, 100*time.Millisecond, 5*time.Millisecond)
+	// Trigger the stats collection.
+	c := make(chan prometheus.Metric)
+	pke.Collect(c)
+
+	// Check the collected stats.
+	metric, _ := pke.Addr4StatsMap["assigned-addresses"].GetMetricWith(
+		prometheus.Labels{
+			"subnet":         "7",
+			"subnet_id":      "7",
+			"prefix":         "",
+			"shared_network": "",
+		},
+	)
+	require.EqualValues(t, 13.0, testutil.ToFloat64(metric))
 
 	// check if pkt4-nak-received is 19
-	metric, _ := pke.PktStatsMap["pkt4-nak-received"].Stat.GetMetricWith(prometheus.Labels{"operation": "nak"})
+	metric, _ = pke.PktStatsMap["pkt4-nak-received"].Stat.GetMetricWith(prometheus.Labels{"operation": "nak"})
 	require.Equal(t, 19.0, testutil.ToFloat64(metric))
 
 	require.False(t, gock.HasUnmatchedRequest())
 }
 
-// The Kea statistic-get-all response fetched from the Kea DHCPv6 demo container.
+// The Kea statistic-get-all response fetched from the Kea demo containers.
 //
-//go:embed testdata/kea-dhcp6-statistic-get-all-rsp.json
-var kea6ResponseFromDemo []byte
+//go:embed testdata/kea-prior-2.4.0-dhcp6-statistic-get-all-rsp.json
+var kea6ResponsePrior2_4_0 []byte
+
+//go:embed testdata/kea-2.4.0-dhcp4-statistic-get-all-rsp.json
+var kea4Response2_4_0 []byte
+
+//go:embed testdata/kea-2.4.0-dhcp6-statistic-get-all-rsp.json
+var kea6Response2_4_0 []byte
 
 // Check starting PromKeaExporter and collecting stats using the real Kea
-// response.
-func TestPromKeaExporterStartDemoResponse(t *testing.T) {
+// response returned by the Kea prior to 2.4.0 version.
+func TestPromKeaExporterStartKeaPrior2_4_0(t *testing.T) {
 	defer gock.Off()
 	gock.CleanUnmatchedRequest()
 	defer gock.CleanUnmatchedRequest()
@@ -154,7 +160,7 @@ func TestPromKeaExporterStartDemoResponse(t *testing.T) {
 		Post("/").
 		Persist().
 		Reply(200).
-		BodyString(string(kea6ResponseFromDemo))
+		BodyString(string(kea6ResponsePrior2_4_0))
 
 	gock.New("http://0.1.2.3:1234/").
 		JSON(map[string]interface{}{
@@ -172,95 +178,213 @@ func TestPromKeaExporterStartDemoResponse(t *testing.T) {
 
 	fam := newFakeMonitorWithDefaultsDHCPv6Only()
 
-	pke := NewPromKeaExporter("foo", 1234, 5*time.Millisecond, true, fam)
+	pke := NewPromKeaExporter("foo", 1234, true, fam)
 	defer pke.Shutdown()
 
 	gock.InterceptClient(fam.HTTPClient.client)
 
-	// start exporter
+	// Start exporter and trigger the stats collection.
 	pke.Start()
-	require.NotNil(t, pke.Ticker)
+	c := make(chan prometheus.Metric)
+	pke.Collect(c)
 
-	require.Eventually(t, func() bool {
-		// check if assigned-addresses is 13
-		metric, _ := pke.Adr6StatsMap["total-nas"].GetMetricWith(
-			prometheus.Labels{
-				"subnet":    "6",
-				"subnet_id": "6",
-				"prefix":    "",
-			},
-		)
-		return testutil.ToFloat64(metric) == 36893488147419103000
-	}, 500*time.Millisecond, 10*time.Millisecond)
+	// Check the collected stats.
+	metric, _ := pke.Addr6StatsMap["total-nas"].GetMetricWith(
+		prometheus.Labels{
+			"subnet":         "6",
+			"subnet_id":      "6",
+			"prefix":         "",
+			"shared_network": "",
+		},
+	)
+	require.EqualValues(t, 36893488147419103000., testutil.ToFloat64(metric))
 
 	// The response is pretty big, so some metrics are available earlier than
 	// others.
-	require.Eventually(t, func() bool {
-		metric, _ := pke.PktStatsMap["pkt6-reply-sent"].Stat.GetMetricWith(prometheus.Labels{"operation": "reply"})
-		return testutil.ToFloat64(metric) == 4489.0
-	}, 500*time.Millisecond, 10*time.Millisecond)
+	metric, _ = pke.PktStatsMap["pkt6-reply-sent"].Stat.GetMetricWith(prometheus.Labels{"operation": "reply"})
+	require.EqualValues(t, 4489.0, testutil.ToFloat64(metric))
 
 	require.False(t, gock.HasUnmatchedRequest())
 }
 
-// Test if the Kea JSON get-all-stats response is unmarshal correctly.
-func TestUnmarshalKeaGetAllStatisticsResponse(t *testing.T) {
-	// Arrange
-	rawResponse := `
-	[
-		{
-			"arguments": {
-				"cumulative-assigned-addresses": [ [0, "2021-10-14 10:44:18.687247"] ],
-				"declined-addresses": [ [0, "2021-10-14 10:44:18.687235"] ],
-				"pkt4-ack-received": [ [0, "2021-10-14 10:44:18.672377"] ],
-				"pkt4-ack-sent": [ [0, "2021-10-14 10:44:18.672378"] ],
-				"pkt4-decline-received": [ [0, "2021-10-14 10:44:18.672379"] ],
-				"pkt4-discover-received": [ [0, "2021-10-14 10:44:18.672380"] ],
-				"pkt4-inform-received": [ [0, "2021-10-14 10:44:18.672380"] ],
-				"pkt4-nak-received": [ [0, "2021-10-14 10:44:18.672381"] ],
-				"pkt4-nak-sent": [ [0, "2021-10-14 10:44:18.672382"] ],
-				"pkt4-offer-received": [ [0, "2021-10-14 10:44:18.672382"] ],
-				"pkt4-offer-sent": [ [0, "2021-10-14 10:44:18.672383"] ],
-				"pkt4-parse-failed": [ [0, "2021-10-14 10:44:18.672384"] ],
-				"pkt4-receive-drop": [ [0, "2021-10-14 10:44:18.672389"] ],
-				"pkt4-received": [ [0, "2021-10-14 10:44:18.672390"] ],
-				"pkt4-release-received": [ [0, "2021-10-14 10:44:18.672390"] ],
-				"pkt4-request-received": [ [0, "2021-10-14 10:44:18.672391"] ],
-				"pkt4-sent": [ [0, "2021-10-14 10:44:18.672392"] ],
-				"pkt4-unknown-received": [ [0, "2021-10-14 10:44:18.672392"] ],
-				"reclaimed-declined-addresses": [ [0, "2021-10-14 10:44:18.687239"] ],
-				"reclaimed-leases": [ [0, "2021-10-14 10:44:18.687243"] ],
-				"subnet[1].assigned-addresses": [ [0, "2021-10-14 10:44:18.687253"] ],
-				"subnet[1].cumulative-assigned-addresses": [ [0, "2021-10-14 10:44:18.687229"] ],
-				"subnet[1].declined-addresses": [ [0, "2021-10-14 10:44:18.687266"] ],
-				"subnet[1].reclaimed-declined-addresses": [ [0, "2021-10-14 10:44:18.687274"] ],
-				"subnet[1].reclaimed-leases": [ [0, "2021-10-14 10:44:18.687282"] ],
-				"subnet[1].total-addresses": [ [200, "2021-10-14 10:44:18.687221"] ]
-			},
-			"result": 0
+// Check starting PromKeaExporter and collecting stats using the real Kea
+// response returned by the Kea DHCPv4 in 2.4.0 version.
+func TestPromKeaExporterStartKea2_4_0DHCPv4(t *testing.T) {
+	defer gock.Off()
+	gock.CleanUnmatchedRequest()
+	defer gock.CleanUnmatchedRequest()
+	gock.New("http://0.1.2.3:1234/").
+		JSON(map[string]interface{}{
+			"command":   "statistic-get-all",
+			"service":   []string{"dhcp4"},
+			"arguments": map[string]string{},
+		}).
+		Post("/").
+		Persist().
+		Reply(200).
+		BodyString(string(kea4Response2_4_0))
+
+	gock.New("http://0.1.2.3:1234/").
+		JSON(map[string]interface{}{
+			"command":   "subnet4-list",
+			"service":   []string{"dhcp4"},
+			"arguments": map[string]string{},
+		}).
+		Post("/").
+		Persist().
+		Reply(200).
+		BodyString(`[{
+			"result": 3,
+			"text": "Command not supported"
+		}]`)
+
+	fam := newFakeMonitorWithDefaultsDHCPv4Only()
+
+	pke := NewPromKeaExporter("foo", 1234, true, fam)
+	defer pke.Shutdown()
+
+	gock.InterceptClient(fam.HTTPClient.client)
+
+	// Start exporter and trigger the stats collection.
+	pke.Start()
+	c := make(chan prometheus.Metric)
+	pke.Collect(c)
+
+	// Check the collected stats.
+	metric, _ := pke.Addr4StatsMap["total-addresses"].GetMetricWith(
+		prometheus.Labels{
+			"subnet":         "22",
+			"subnet_id":      "22",
+			"prefix":         "",
+			"shared_network": "",
 		},
-		{
-			"result": 1,
-			"text": "Unable to forward command to the dhcp6 service: No such file or directory. The server is likely to be offline"
-		}
-	]`
+	)
+	require.EqualValues(t, 150., testutil.ToFloat64(metric))
 
-	// Act
-	var response GetAllStatisticsResponse
-	err := json.Unmarshal([]byte(rawResponse), &response)
+	metric, _ = pke.PktStatsMap["pkt4-ack-received"].Stat.GetMetricWith(prometheus.Labels{"operation": "ack"})
+	require.EqualValues(t, 42.0, testutil.ToFloat64(metric))
 
-	// Assert
-	require.NoError(t, err)
-	require.Len(t, response, 2)
-	require.Len(t, response[0], 26)
-	require.Nil(t, response[1])
-	require.EqualValues(t, 200, response[0]["subnet[1].total-addresses"].Value)
-	require.NotNil(t, response[0]["reclaimed-leases"].Timestamp)
-	require.EqualValues(t, "2021-10-14 10:44:18.687243", *response[0]["reclaimed-leases"].Timestamp)
+	metric, _ = pke.Addr4StatsMap["pool-total-addresses"].GetMetricWith(
+		prometheus.Labels{
+			"subnet":         "11",
+			"subnet_id":      "11",
+			"prefix":         "",
+			"pool_id":        "0",
+			"shared_network": "",
+		},
+	)
+	require.EqualValues(t, 50., testutil.ToFloat64(metric))
+
+	require.False(t, gock.HasUnmatchedRequest())
 }
 
-// Test if the Kea JSON subnet4-list or subnet6-list response in unmarshal correctly.
-func TestUnmarshalSubnetListOKResponse(t *testing.T) {
+// Check starting PromKeaExporter and collecting stats using the real Kea
+// response returned by the Kea DHCPv6 in 2.4.0 version.
+func TestPromKeaExporterStartKea2_4_0DHCPv6(t *testing.T) {
+	defer gock.Off()
+	gock.CleanUnmatchedRequest()
+	defer gock.CleanUnmatchedRequest()
+	gock.New("http://0.1.2.3:1234/").
+		JSON(map[string]interface{}{
+			"command":   "statistic-get-all",
+			"service":   []string{"dhcp6"},
+			"arguments": map[string]string{},
+		}).
+		Post("/").
+		Persist().
+		Reply(200).
+		BodyString(string(kea6Response2_4_0))
+
+	gock.New("http://0.1.2.3:1234/").
+		JSON(map[string]interface{}{
+			"command":   "subnet6-list",
+			"service":   []string{"dhcp6"},
+			"arguments": map[string]string{},
+		}).
+		Post("/").
+		Persist().
+		Reply(200).
+		BodyString(`[{
+			"result": 3,
+			"text": "Command not supported"
+		}]`)
+
+	fam := newFakeMonitorWithDefaultsDHCPv6Only()
+
+	pke := NewPromKeaExporter("foo", 1234, true, fam)
+	defer pke.Shutdown()
+
+	gock.InterceptClient(fam.HTTPClient.client)
+
+	// Start exporter and trigger the stats collection.
+	pke.Start()
+	c := make(chan prometheus.Metric)
+	pke.Collect(c)
+
+	// Check the collected stats.
+	metric, _ := pke.Addr6StatsMap["total-nas"].GetMetricWith(
+		prometheus.Labels{
+			"subnet":         "1",
+			"subnet_id":      "1",
+			"prefix":         "",
+			"shared_network": "",
+		},
+	)
+	require.EqualValues(t, 844424930131968., testutil.ToFloat64(metric))
+
+	metric, _ = pke.Addr6StatsMap["total-nas"].GetMetricWith(
+		prometheus.Labels{
+			"subnet":         "1",
+			"subnet_id":      "1",
+			"prefix":         "",
+			"shared_network": "",
+		},
+	)
+	require.EqualValues(t, 844424930131968., testutil.ToFloat64(metric))
+
+	metric, _ = pke.Addr6StatsMap["total-pds"].GetMetricWith(
+		prometheus.Labels{
+			"subnet":         "1",
+			"subnet_id":      "1",
+			"prefix":         "",
+			"shared_network": "",
+		},
+	)
+	require.EqualValues(t, 512., testutil.ToFloat64(metric))
+
+	// The response is pretty big, so some metrics are available earlier than
+	// others.
+	metric, _ = pke.PktStatsMap["pkt6-reply-sent"].Stat.GetMetricWith(prometheus.Labels{"operation": "reply"})
+	require.EqualValues(t, 42.0, testutil.ToFloat64(metric))
+
+	metric, _ = pke.Addr6StatsMap["pool-total-nas"].GetMetricWith(
+		prometheus.Labels{
+			"subnet":         "1",
+			"subnet_id":      "1",
+			"prefix":         "",
+			"pool_id":        "0",
+			"shared_network": "",
+		},
+	)
+	require.EqualValues(t, 844424930131968., testutil.ToFloat64(metric))
+
+	metric, _ = pke.Addr6StatsMap["pool-pd-total-pds"].GetMetricWith(
+		prometheus.Labels{
+			"subnet":         "1",
+			"subnet_id":      "1",
+			"prefix":         "",
+			"pool_id":        "0",
+			"shared_network": "",
+		},
+	)
+	require.EqualValues(t, 512., testutil.ToFloat64(metric))
+
+	require.False(t, gock.HasUnmatchedRequest())
+}
+
+// Test if the Kea JSON subnet4-list or subnet6-list response in unmarshal
+// correctly. Uses the response from Kea prior to 2.7.8 version.
+func TestUnmarshalSubnetListOKResponsePriorKea2_7_8(t *testing.T) {
 	// Arrange
 	rawResponse := `[{
 		"result": 0,
@@ -280,13 +404,49 @@ func TestUnmarshalSubnetListOKResponse(t *testing.T) {
 	}]`
 
 	// Act
-	response := NewSubnetList()
+	response := newSubnetList()
 	err := json.Unmarshal([]byte(rawResponse), &response)
 
 	// Assert
 	require.NoError(t, err)
 	require.Len(t, response, 2)
-	require.EqualValues(t, "192.0.2.0/24", response[100])
+	require.Contains(t, response, 100)
+	require.EqualValues(t, "192.0.2.0/24", response[100].prefix)
+	require.Empty(t, response[100].sharedNetwork)
+}
+
+// Test if the Kea JSON subnet4-list or subnet6-list response in unmarshal
+// correctly. Uses the response from Kea 2.7.8 version.
+func TestUnmarshalSubnetListOKResponseKea2_7_8(t *testing.T) {
+	// Arrange
+	rawResponse := `[{
+		"result": 0,
+		"text": "2 IPv4 subnets found",
+		"arguments": {
+			"subnets": [
+				{
+					"id": 10,
+					"subnet": "10.0.0.0/8"
+				},
+				{
+					"id": 100,
+					"subnet": "192.0.2.0/24",
+					"shared-network-name": "foo"
+				}
+			]
+		}
+	}]`
+
+	// Act
+	response := newSubnetList()
+	err := json.Unmarshal([]byte(rawResponse), &response)
+
+	// Assert
+	require.NoError(t, err)
+	require.Len(t, response, 2)
+	require.Contains(t, response, 100)
+	require.EqualValues(t, "192.0.2.0/24", response[100].prefix)
+	require.EqualValues(t, "foo", response[100].sharedNetwork)
 }
 
 // Test the Kea JSON subnet4-list or subnet6-list response when the hook is not installed.
@@ -300,7 +460,7 @@ func TestUnmarshalSubnetListUnsupportedResponse(t *testing.T) {
 	]`
 
 	// Act
-	response := NewSubnetList()
+	response := newSubnetList()
 	err := json.Unmarshal([]byte(rawResponse), &response)
 
 	// Assert
@@ -314,7 +474,7 @@ func TestUnmarshalSubnetListErrorResponse(t *testing.T) {
 	rawResponse := ""
 
 	// Act
-	response := NewSubnetList()
+	response := newSubnetList()
 	err := json.Unmarshal([]byte(rawResponse), &response)
 
 	// Assert
@@ -357,7 +517,8 @@ func TestSubnetPrefixInPrometheusMetrics(t *testing.T) {
 				"subnets": [
 					{
 						"id": 7,
-						"subnet": "10.0.0.0/8"
+						"subnet": "10.0.0.0/8",
+						"shared-network-name": "foobar"
 					}
 				]
 			}
@@ -365,26 +526,28 @@ func TestSubnetPrefixInPrometheusMetrics(t *testing.T) {
 
 	fam := newFakeMonitorWithDefaults()
 
-	pke := NewPromKeaExporter("foo", 1234, 1*time.Millisecond, true, fam)
+	pke := NewPromKeaExporter("foo", 1234, true, fam)
 	defer pke.Shutdown()
 
 	gock.InterceptClient(fam.HTTPClient.client)
+
+	// Act
 	pke.Start()
+	c := make(chan prometheus.Metric)
+	pke.Collect(c)
 
-	// Act & Assert
-	// Wait for collecting.
-	require.Eventually(t, func() bool {
-		metric, _ := pke.Adr4StatsMap["assigned-addresses"].GetMetricWith(
-			prometheus.Labels{
-				"subnet_id": "7",
-				"prefix":    "10.0.0.0/8",
-				"subnet":    "10.0.0.0/8",
-			},
-		)
-
-		return testutil.ToFloat64(metric) == 13.0
-	}, 100*time.Millisecond, 5*time.Millisecond)
+	// Assert
+	metric, err := pke.Addr4StatsMap["assigned-addresses"].GetMetricWith(
+		prometheus.Labels{
+			"subnet_id":      "7",
+			"prefix":         "10.0.0.0/8",
+			"subnet":         "10.0.0.0/8",
+			"shared_network": "foobar",
+		},
+	)
 
+	require.NoError(t, err)
+	require.Equal(t, 13.0, testutil.ToFloat64(metric))
 	require.NotZero(t, testutil.ToFloat64(pke.Global4StatMap["cumulative-assigned-addresses"]))
 }
 
@@ -409,8 +572,9 @@ func newFakeKeaCASender() *FakeKeaCASender {
 						Subnet: "foo",
 					},
 					{
-						ID:     42,
-						Subnet: "bar",
+						ID:                42,
+						Subnet:            "bar",
+						SharedNetworkName: "baz",
 					},
 				},
 			},
@@ -427,94 +591,96 @@ func (s *FakeKeaCASender) sendCommandRaw(request []byte) ([]byte, error) {
 	return s.payload, s.err
 }
 
-// Test that the lazy subnet name lookup is constructed properly.
-func TestNewLazySubnetPrefixLookup(t *testing.T) {
+// Test that the lazy subnet lookup is constructed properly.
+func TestNewLazySubnetLookup(t *testing.T) {
 	// Arrange
 	sender := newFakeKeaCASender()
 
 	// Act
-	lookup := newLazySubnetPrefixLookup(sender)
+	lookup := newLazySubnetLookup(sender)
 
 	// Assert
 	require.NotNil(t, lookup)
 	require.Zero(t, sender.callCount)
 }
 
-// Test that the subnet names are retrieved.
-func TestLazySubnetNameLookupFetchesNames(t *testing.T) {
+// Test that the subnet data are retrieved.
+func TestLazySubnetLookupFetchesData(t *testing.T) {
 	// Arrange
 	sender := newFakeKeaCASender()
-	lookup := newLazySubnetPrefixLookup(sender)
+	lookup := newLazySubnetLookup(sender)
 
 	// Act
-	name1, ok1 := lookup.getPrefix(1)
-	name42, ok42 := lookup.getPrefix(42)
-	name0, ok0 := lookup.getPrefix(0)
-	nameMinus1, okMinus1 := lookup.getPrefix(-1)
+	info1, ok1 := lookup.getSubnetInfo(1)
+	info42, ok42 := lookup.getSubnetInfo(42)
+	info0, ok0 := lookup.getSubnetInfo(0)
+	infoMinus1, okMinus1 := lookup.getSubnetInfo(-1)
 
 	// Assert
 	require.True(t, ok1)
-	require.EqualValues(t, "foo", name1)
+	require.EqualValues(t, "foo", info1.prefix)
+	require.Empty(t, info1.sharedNetwork)
 
 	require.True(t, ok42)
-	require.EqualValues(t, "bar", name42)
+	require.EqualValues(t, "bar", info42.prefix)
+	require.EqualValues(t, "baz", info42.sharedNetwork)
 
 	require.False(t, ok0)
-	require.Empty(t, name0)
+	require.Empty(t, info0.prefix)
 
 	require.False(t, okMinus1)
-	require.Empty(t, nameMinus1)
+	require.Empty(t, infoMinus1.prefix)
 }
 
-// Test that subnet names are fetched only once.
-func TestLazySubnetNameLookupFetchesOnlyOnce(t *testing.T) {
+// Test that subnets are fetched only once.
+func TestLazySubnetLookupFetchesOnlyOnce(t *testing.T) {
 	// Arrange
 	sender := newFakeKeaCASender()
-	lookup := newLazySubnetPrefixLookup(sender)
+	lookup := newLazySubnetLookup(sender)
 
 	// Act
-	_, _ = lookup.getPrefix(1)
-	_, _ = lookup.getPrefix(1)
-	_, _ = lookup.getPrefix(1)
-	_, _ = lookup.getPrefix(42)
-	_, _ = lookup.getPrefix(100)
+	_, _ = lookup.getSubnetInfo(1)
+	_, _ = lookup.getSubnetInfo(1)
+	_, _ = lookup.getSubnetInfo(1)
+	_, _ = lookup.getSubnetInfo(42)
+	_, _ = lookup.getSubnetInfo(100)
 
 	// Assert
 	require.EqualValues(t, 1, sender.callCount)
 }
 
-// Test that subnet names are fetched only once even if an error occurs.
-func TestLazySubnetNameLookupFetchesOnlyOnceEvenIfError(t *testing.T) {
+// Test that subnets are fetched only once even if an error occurs.
+func TestLazySubnetLookupFetchesOnlyOnceEvenIfError(t *testing.T) {
 	// Arrange
 	sender := newFakeKeaCASender()
 	sender.payload = nil
 	sender.err = errors.New("baz")
-	lookup := newLazySubnetPrefixLookup(sender)
+	lookup := newLazySubnetLookup(sender)
 
 	for _, subnetID := range []int{1, 1, 1, 42, 100} {
 		// Act
-		_, ok := lookup.getPrefix(subnetID)
+		_, ok := lookup.getSubnetInfo(subnetID)
 		// Assert
 		require.False(t, ok)
 	}
 	require.EqualValues(t, 1, sender.callCount)
 }
 
-// Test that subnet names are fetched again after changing the family.
-func TestLazySubnetNameLookupFetchesAgainWhenFamilyChanged(t *testing.T) {
+// Test that subnets are fetched again after changing the family.
+func TestLazySubnetLookupFetchesAgainWhenFamilyChanged(t *testing.T) {
 	// Arrange
 	sender := newFakeKeaCASender()
-	lookup := newLazySubnetPrefixLookup(sender)
+	lookup := newLazySubnetLookup(sender)
 
 	// Act
-	_, _ = lookup.getPrefix(1)
+	_, _ = lookup.getSubnetInfo(1)
 	lookup.setFamily(6)
 	sender.payload = nil
-	name, ok := lookup.getPrefix(1)
+	info, ok := lookup.getSubnetInfo(1)
 
 	// Assert
 	require.False(t, ok)
-	require.Empty(t, name)
+	require.Empty(t, info.prefix)
 	require.EqualValues(t, 2, sender.callCount)
 }
 
@@ -534,26 +700,27 @@ func TestDisablePerSubnetStatsCollecting(t *testing.T) {
 		Reply(200).
 		BodyString(`[{"result":0, "arguments": {
                     "subnet[7].assigned-addresses": [ [ 13, "2019-07-30 10:04:28.386740" ] ],
-                    "pkt4-nak-received": [ [ 19, "2019-07-30 10:04:28.386733" ] ]
+                    "pkt4-nak-received": [ [ 19, "2019-07-30 10:04:28.386733" ] ],
+					"subnet[7].pool[0].assigned-addresses": [ [ 13, "2019-07-30 10:04:28.386740" ] ],
+					"subnet[7].pd-pool[0].assigned-addresses": [ [ 13, "2019-07-30 10:04:28.386740" ] ]
                 }}]`)
 
 	fam := newFakeMonitorWithDefaultsDHCPv4Only()
 
 	// Act
-	pke := NewPromKeaExporter("foo", 1234, 1*time.Millisecond, false, fam)
+	pke := NewPromKeaExporter("foo", 1234, false, fam)
 	defer pke.Shutdown()
 	gock.InterceptClient(fam.HTTPClient.client)
 	pke.Start()
+	c := make(chan prometheus.Metric)
+	pke.Collect(c)
 
 	// Assert
-	// Wait for collecting.
-	require.Eventually(t, func() bool {
-		metric, _ := pke.PktStatsMap["pkt4-nak-received"].Stat.GetMetricWith(prometheus.Labels{"operation": "nak"})
-		// Check if pkt4-nak-received has expected value.
-		return testutil.ToFloat64(metric) == 19.0
-	}, 100*time.Millisecond, 5*time.Millisecond)
+	metric, _ := pke.PktStatsMap["pkt4-nak-received"].Stat.GetMetricWith(prometheus.Labels{"operation": "nak"})
+	// Check if pkt4-nak-received has expected value.
+	require.EqualValues(t, 19.0, testutil.ToFloat64(metric))
 
-	require.Nil(t, pke.Adr4StatsMap)
+	require.Nil(t, pke.Addr4StatsMap)
 
 	// Has no unnecessary calls.
 	require.False(t, gock.HasUnmatchedRequest())
@@ -588,18 +755,15 @@ func TestCollectingGlobalStatistics(t *testing.T) {
 
 	fam := newFakeMonitorWithDefaults()
 
-	pke := NewPromKeaExporter("foo", 1234, 1*time.Millisecond, true, fam)
+	pke := NewPromKeaExporter("foo", 1234, true, fam)
 	defer pke.Shutdown()
 
 	gock.InterceptClient(fam.HTTPClient.client)
 	pke.Start()
+	c := make(chan prometheus.Metric)
+	pke.Collect(c)
 
 	// Act & Assert
-	// Wait for collecting.
-	require.Eventually(t, func() bool {
-		return testutil.ToFloat64(pke.Global4StatMap["cumulative-assigned-addresses"]) > 0
-	}, 100*time.Millisecond, 5*time.Millisecond)
-
 	require.Equal(t, 13.0, testutil.ToFloat64(pke.Global4StatMap["cumulative-assigned-addresses"]))
 	require.Equal(t, 14.0, testutil.ToFloat64(pke.Global4StatMap["declined-addresses"]))
 	require.Equal(t, 15.0, testutil.ToFloat64(pke.Global4StatMap["reclaimed-leases"]))
@@ -639,7 +803,7 @@ func TestSendRequestOnlyToDetectedDaemons(t *testing.T) {
 	fam.Apps[0].(*KeaApp).ConfiguredDaemons = []string{"dhcp6"}
 	fam.Apps[0].(*KeaApp).ActiveDaemons = []string{"dhcp6"}
 
-	pke := NewPromKeaExporter("foo", 1234, 1*time.Millisecond, true, fam)
+	pke := NewPromKeaExporter("foo", 1234, true, fam)
 	defer pke.Shutdown()
 
 	gock.InterceptClient(fam.HTTPClient.client)
@@ -677,7 +841,7 @@ func TestEncounteredUnsupportedStatisticsAreAppendedToIgnoreList(t *testing.T) {
 
 	fam := newFakeMonitorWithDefaults()
 
-	pke := NewPromKeaExporter("foo", 1234, 1*time.Millisecond, true, fam)
+	pke := NewPromKeaExporter("foo", 1234, true, fam)
 	defer pke.Shutdown()
 
 	gock.InterceptClient(fam.HTTPClient.client)
@@ -689,3 +853,19 @@ func TestEncounteredUnsupportedStatisticsAreAppendedToIgnoreList(t *testing.T) {
 	require.NoError(t, err)
 	require.Contains(t, pke.ignoredStats, "foo")
 }
+
+// Test that the Describe method does nothing.
+func TestDescribe(t *testing.T) {
+	// Arrange
+	fam := newFakeMonitorWithDefaults()
+	pke := NewPromKeaExporter("foo", 1234, true, fam)
+	ch := make(chan *prometheus.Desc, 1)
+	defer close(ch)
+	defer pke.Shutdown()
+
+	// Act
+	pke.Describe(ch)
+
+	// Assert
+	require.Empty(t, ch)
+}
