@@ -18,13 +18,26 @@ import (
 	gomock "go.uber.org/mock/gomock"
 	"gopkg.in/h2non/gock.v1"
 	bind9config "isc.org/stork/appcfg/bind9"
+	pdnsconfig "isc.org/stork/appcfg/pdns"
 	"isc.org/stork/appdata/bind9stats"
+	pdnsdata "isc.org/stork/appdata/pdns"
 	"isc.org/stork/testutil"
 	storkutil "isc.org/stork/util"
 )
 
 //go:generate mockgen -package=agent -destination=zoneinventorymock_test.go -mock_names=zoneInventoryAXFRExecutor=MockZoneInventoryAXFRExecutor isc.org/stork/agent zoneInventoryAXFRExecutor
 
+// This function generates a root zone.
+func generateRootZone() *bind9stats.Zone {
+	return &bind9stats.Zone{
+		ZoneName: ".",
+		Class:    "IN",
+		Serial:   1,
+		Type:     "master",
+		Loaded:   time.Date(2025, 1, 1, 15, 19, 20, 0, time.UTC),
+	}
+}
+
 // This function generates a collection of zones used in the benchmarks.
 // The function argument specifies the number of zones to be generated.
 func generateRandomZones(num int) []*bind9stats.Zone {
@@ -42,6 +55,21 @@ func generateRandomZones(num int) []*bind9stats.Zone {
 	return zones
 }
 
+// This function generates a collection of zones returned by PowerDNS API.
+func generateRandomPDNSZones(num int) []*pdnsdata.Zone {
+	generatedZones := testutil.GenerateRandomZones(num)
+	var zones []*pdnsdata.Zone
+	for _, generatedZone := range generatedZones {
+		zones = append(zones, &pdnsdata.Zone{
+			ZoneName: generatedZone.Name,
+			Serial:   generatedZone.Serial,
+			Kind:     generatedZone.Type,
+			URL:      "/api/v1/servers/localhost/zones/" + generatedZone.Name,
+		})
+	}
+	return zones
+}
+
 // Sort zones and return the one at specified index.
 func getOrderedZoneByIndex(zones []*bind9stats.Zone, index int) *bind9stats.Zone {
 	slices.SortFunc(zones, func(zone1, zone2 *bind9stats.Zone) int {
@@ -69,6 +97,25 @@ func setGetViewsResponseOK(t *testing.T, response map[string]any) (*bind9StatsCl
 	}
 }
 
+// Setup stub response returning zones from the PowerDNS API.
+func setGetViewsPowerDNSResponseOK(t *testing.T, response []*pdnsdata.Zone) (*pdnsClient, func()) {
+	zones, err := json.Marshal(response)
+	require.NoError(t, err)
+
+	gock.New("http://localhost:5380/").
+		Get("api/v1/servers/localhost/zones").
+		Persist().
+		Reply(http.StatusOK).
+		AddHeader("Content-Type", "application/json").
+		BodyString(string(zones))
+	pdnsClient := newPDNSClient()
+	gock.InterceptClient(pdnsClient.innerClient.GetClient())
+
+	return pdnsClient, func() {
+		gock.Off()
+	}
+}
+
 // Setup stub response from the BIND9 stats (benchmark edition).
 func setBenchmarkGetViewsResponseOK(b *testing.B, response map[string]any) (*bind9StatsClient, func()) {
 	zones, err := json.Marshal(response)
@@ -98,6 +145,14 @@ func parseDefaultBind9Config(t *testing.T) *bind9config.Config {
 	return bind9Config
 }
 
+// Parse the default PowerDNS config file.
+func parseDefaultPDNSConfig(t *testing.T) *pdnsconfig.Config {
+	pdnsConfig, err := pdnsconfig.NewParser().ParseFile("testdata/pdns.conf")
+	require.NoError(t, err)
+	require.NotNil(t, pdnsConfig)
+	return pdnsConfig
+}
+
 // Parse the default BIND9 config file for benchmark.
 func parseBenchmarkDefaultBind9Config(b *testing.B) *bind9config.Config {
 	bind9Config, err := bind9config.NewParser().ParseFile("testdata/named.conf")
@@ -625,7 +680,8 @@ func TestZoneInventoryTransition(t *testing.T) {
 // Test populating the zones from the DNS server to memory and disk.
 func TestZoneInventoryPopulateMemoryDisk(t *testing.T) {
 	// Setup server response.
-	defaultZones := generateRandomZones(10)
+	defaultZones := []*bind9stats.Zone{generateRootZone()}
+	defaultZones = append(defaultZones, generateRandomZones(9)...)
 	bindZones := generateRandomZones(20)
 	response := map[string]any{
 		"views": map[string]any{
@@ -665,10 +721,10 @@ func TestZoneInventoryPopulateMemoryDisk(t *testing.T) {
 
 	// Make sure that the views contain zones.
 	for _, zone := range defaultZones {
-		require.FileExists(t, path.Join(sandbox.BasePath, "_default", zone.Name()))
+		require.FileExists(t, path.Join(sandbox.BasePath, "_default", getViewIOZoneFileName(zone.Name())))
 	}
 	for _, zone := range bindZones {
-		require.FileExists(t, path.Join(sandbox.BasePath, "_bind", zone.Name()))
+		require.FileExists(t, path.Join(sandbox.BasePath, "_bind", getViewIOZoneFileName(zone.Name())))
 	}
 
 	// Make sure that the inventory is in the correct state.
@@ -751,10 +807,10 @@ func TestZoneInventoryPopulateDisk(t *testing.T) {
 
 	// Make sure that the views contain zones.
 	for _, zone := range defaultZones {
-		require.FileExists(t, path.Join(sandbox.BasePath, "_default", zone.Name()))
+		require.FileExists(t, path.Join(sandbox.BasePath, "_default", getViewIOZoneFileName(zone.Name())))
 	}
 	for _, zone := range bindZones {
-		require.FileExists(t, path.Join(sandbox.BasePath, "_bind", zone.Name()))
+		require.FileExists(t, path.Join(sandbox.BasePath, "_bind", getViewIOZoneFileName(zone.Name())))
 	}
 	// Make sure that the inventory is in the correct state.
 	require.Equal(t, zoneInventoryStatePopulated, inventory.getCurrentState().name)
@@ -873,7 +929,8 @@ func TestZoneInventoryPopulateAwaitBackgroundTasks(t *testing.T) {
 // Test loading the inventory from disk to memory.
 func TestZoneInventoryLoadMemoryDisk(t *testing.T) {
 	// Setup server response.
-	defaultZones := generateRandomZones(10)
+	defaultZones := []*bind9stats.Zone{generateRootZone()}
+	defaultZones = append(defaultZones, generateRandomZones(9)...)
 	bindZones := generateRandomZones(20)
 	response := map[string]any{
 		"views": map[string]any{
@@ -981,7 +1038,8 @@ func TestZoneInventoryLoadMemory(t *testing.T) {
 // Test loading the inventory from disk.
 func TestZoneInventoryLoadDisk(t *testing.T) {
 	// Setup server response.
-	defaultZones := generateRandomZones(10)
+	defaultZones := []*bind9stats.Zone{generateRootZone()}
+	defaultZones = append(defaultZones, generateRandomZones(9)...)
 	bindZones := generateRandomZones(20)
 	response := map[string]any{
 		"views": map[string]any{
@@ -1031,13 +1089,17 @@ func TestZoneInventoryLoadDisk(t *testing.T) {
 	require.NoError(t, err)
 
 	// Make sure that the views have been reloaded and contain zones.
-	zone, err := inventory.getZoneInView("_default", defaultZones[0].Name())
-	require.NoError(t, err)
-	require.NotNil(t, zone)
+	for _, defaultZone := range defaultZones {
+		zone, err := inventory.getZoneInView("_default", defaultZone.Name())
+		require.NoError(t, err)
+		require.NotNil(t, zone)
+	}
 
-	zone, err = inventory.getZoneInView("_bind", bindZones[0].Name())
-	require.NoError(t, err)
-	require.NotNil(t, zone)
+	for _, bindZone := range bindZones {
+		zone, err := inventory.getZoneInView("_bind", bindZone.Name())
+		require.NoError(t, err)
+		require.NotNil(t, zone)
+	}
 
 	// Make sure that the inventory is in the correct state and that
 	// the inventory creation time was read from disk.
@@ -1231,8 +1293,10 @@ func TestZoneInventoryReceiveZonesMemoryStorage(t *testing.T) {
 			// Views should be sorted by name, so _bind goes first.
 			if i < 20 {
 				require.Equal(t, "_bind", zone.ViewName)
+				require.False(t, zone.RPZ)
 			} else {
 				require.Equal(t, "_default", zone.ViewName)
+				require.False(t, zone.RPZ)
 			}
 			require.EqualValues(t, 30, zone.TotalZoneCount)
 		}
@@ -1261,6 +1325,7 @@ func TestZoneInventoryReceiveZonesMemoryStorage(t *testing.T) {
 		require.Len(t, receivedZones, 20)
 		for _, zone := range receivedZones {
 			require.Equal(t, "_bind", zone.ViewName)
+			require.False(t, zone.RPZ)
 			require.EqualValues(t, 20, zone.TotalZoneCount)
 		}
 		// Make sure that the inventory is in the correct state.
@@ -1289,6 +1354,7 @@ func TestZoneInventoryReceiveZonesMemoryStorage(t *testing.T) {
 		require.Len(t, receivedZones, 5)
 		for index, zone := range receivedZones {
 			require.Equal(t, "_bind", zone.ViewName)
+			require.False(t, zone.RPZ)
 			require.EqualValues(t, 20, zone.TotalZoneCount)
 			require.Equal(t, getOrderedZoneByIndex(bindZones, index+15).Name(), zone.Name())
 		}
@@ -1466,6 +1532,69 @@ func TestZoneInventoryReceiveZonesDiskStorage(t *testing.T) {
 	})
 }
 
+// Test that the zone inventory correctly identifies the RPZ zones.
+func TestZoneInventoryReceiveZonesRPZ(t *testing.T) {
+	// Setup server response.
+	response := map[string]any{
+		"views": map[string]any{
+			"trusted": map[string]any{
+				"zones": []*bind9stats.Zone{
+					{
+						ZoneName: "rpz.example.com",
+						Class:    "IN",
+						Serial:   1234567890,
+						Type:     "primary",
+						Loaded:   time.Date(2025, 1, 1, 15, 19, 20, 0, time.UTC),
+					},
+				},
+			},
+		},
+	}
+	bind9StatsClient, off := setGetViewsResponseOK(t, response)
+	defer off()
+
+	// Create the inventory.
+	sandbox := testutil.NewSandbox()
+	defer sandbox.Close()
+	storage, err := newZoneInventoryStorageMemoryDisk(sandbox.BasePath)
+	require.NoError(t, err)
+	config := parseDefaultBind9Config(t)
+	inventory := newZoneInventory(storage, config, bind9StatsClient, "localhost", 5380)
+	defer inventory.stop()
+
+	// Populate the zones from the DNS server to the inventory.
+	done, err := inventory.populate(false)
+	require.NoError(t, err)
+	if inventory.getCurrentState().name == zoneInventoryStatePopulating {
+		<-done
+	}
+	err = inventory.getCurrentState().err
+	require.NoError(t, err)
+
+	channel, err := inventory.receiveZones(context.Background(), nil)
+	require.NoError(t, err)
+
+	// Wait for the inventory to start sending zones.
+	require.Eventually(t, func() bool {
+		return inventory.getCurrentState().name == zoneInventoryStateReceivingZones
+	}, time.Second, time.Millisecond)
+
+	// Get the zones from the channel.
+	var receivedZones []*bind9stats.ExtendedZone
+	for result := range channel {
+		require.NoError(t, result.err)
+		receivedZones = append(receivedZones, result.zone)
+	}
+	// Make sure that all zones have been received.
+	require.Len(t, receivedZones, 1)
+	for _, zone := range receivedZones {
+		require.Equal(t, "trusted", zone.ViewName)
+		require.True(t, zone.RPZ)
+	}
+	// Make sure that the inventory is in the correct state.
+	require.Equal(t, zoneInventoryStateReceivedZones, inventory.getCurrentState().name)
+}
+
 // Test that receiving the zones over the channel can be cancelled.
 func TestZoneInventoryReceiveZonesCancel(t *testing.T) {
 	// Setup server response.
@@ -1867,6 +1996,14 @@ func TestZoneInventoryRequestAXFRResponseError(t *testing.T) {
 	require.Nil(t, axfrResponse.envelope)
 }
 
+// Test the function that returns the file name for the zone information file.
+func TestGetViewIOZoneFileName(t *testing.T) {
+	require.Equal(t, "root.zone", getViewIOZoneFileName("."))
+	require.Equal(t, "root.zone", getViewIOZoneFileName("root."))
+	require.Equal(t, "example.com.zone", getViewIOZoneFileName("example.com."))
+	require.Equal(t, "example.com.zone", getViewIOZoneFileName("example.com"))
+}
+
 // Benchmark measuring performance of loading the zones from disk to memory.
 func BenchmarkZoneInventoryLoad(b *testing.B) {
 	testCases := []int{10, 100, 1000, 10000, 100000}
