@@ -197,25 +197,40 @@ func TestCreateHostCmdsReservation(t *testing.T) {
 // reservation from Kea.
 func TestCreateHostCmdsDeletedReservation(t *testing.T) {
 	host := createDefaultTestHost()
-	reservation, err := keaconfig.CreateHostCmdsDeletedReservation(1, host)
-	require.NoError(t, err)
-	require.NotNil(t, reservation)
 
-	// Use the first identifier to delete the reservation.
-	require.Equal(t, "hw-address", reservation.IdentifierType)
-	require.Equal(t, "010203040506", reservation.Identifier)
-	require.EqualValues(t, 123, reservation.SubnetID)
+	for _, expectedOperationTarget := range []keaconfig.HostCmdsOperationTarget{
+		keaconfig.HostCmdsOperationTargetDefault,
+		keaconfig.HostCmdsOperationTargetDatabase,
+		keaconfig.HostCmdsOperationTargetMemory,
+		keaconfig.HostCmdsOperationTargetAll,
+	} {
+		t.Run(string(expectedOperationTarget), func(t *testing.T) {
+			reservation, err := keaconfig.CreateHostCmdsDeletedReservation(
+				1, host, expectedOperationTarget,
+			)
+			require.NoError(t, err)
+			require.NotNil(t, reservation)
+
+			// Use the first identifier to delete the reservation.
+			require.Equal(t, "hw-address", reservation.IdentifierType)
+			require.Equal(t, "010203040506", reservation.Identifier)
+			require.EqualValues(t, 123, reservation.SubnetID)
+			require.Equal(t, expectedOperationTarget, reservation.OperationTarget)
+		})
+	}
 }
 
 // Test that conversion error is returned when the host has no
 // identifiers.
-func TestCreateHostCmdsDeletedReservationNoIdentfiers(t *testing.T) {
+func TestCreateHostCmdsDeletedReservationNoIdentifiers(t *testing.T) {
 	host := createDefaultTestHost()
 	host.identifiers = []struct {
 		Type  string
 		Value []byte
 	}{}
-	reservation, err := keaconfig.CreateHostCmdsDeletedReservation(1, host)
+	reservation, err := keaconfig.CreateHostCmdsDeletedReservation(
+		1, host, keaconfig.HostCmdsOperationTargetDefault,
+	)
 	require.Error(t, err)
 	require.Nil(t, reservation)
 }
@@ -225,7 +240,9 @@ func TestCreateHostCmdsDeletedReservationNoIdentfiers(t *testing.T) {
 func TestCreateHostCmdsDeletedReservationSubnetIDError(t *testing.T) {
 	host := createDefaultTestHost()
 	host.subnetIDTuple.err = errors.New("error getting subnet ID")
-	reservation, err := keaconfig.CreateHostCmdsDeletedReservation(1, host)
+	reservation, err := keaconfig.CreateHostCmdsDeletedReservation(
+		1, host, keaconfig.HostCmdsOperationTargetDefault,
+	)
 	require.Error(t, err)
 	require.Nil(t, reservation)
 }
