@@ -7,6 +7,7 @@ import (
 	"time"
 
 	log "github.com/sirupsen/logrus"
+	agentapi "isc.org/stork/api"
 	"isc.org/stork/appdata/bind9stats"
 	"isc.org/stork/server/agentcomm"
 	dbops "isc.org/stork/server/database"
@@ -55,7 +56,7 @@ func GetAppStatistics(ctx context.Context, agents agentcomm.ConnectedAgents, dbA
 
 	// store all collected details in app db record
 	statsOutput := NamedStatsGetResponse{}
-	err = agents.ForwardToNamedStats(ctx2, dbApp, statsChannel.Address, statsChannel.Port, "", &statsOutput)
+	err = agents.ForwardToNamedStats(ctx2, dbApp, statsChannel.Address, statsChannel.Port, agentapi.ForwardToNamedStatsReq_SERVER, &statsOutput)
 	if err != nil {
 		log.Warnf("Problem retrieving stats from named: %s", err)
 	}
