@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"math"
 	"math/big"
+	"sort"
 	"testing"
 
 	"github.com/go-pg/pg/v10"
@@ -63,55 +64,106 @@ func createStandardKeaMock(t *testing.T, oldStatsFormat bool) func(callNo int, c
 					"subnet[10].%[1]s": [ [ %[4]d, "2019-07-30 10:13:00.000000" ] ],
 					"subnet[10].%[2]s": [ [ %[5]d, "2019-07-30 10:13:00.000000" ] ],
 					"subnet[10].%[3]s": [ [ %[6]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[10].pool[0].%[1]s": [ [ %[4]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[10].pool[0].%[2]s": [ [ %[5]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[10].pool[0].%[3]s": [ [ %[6]d, "2019-07-30 10:13:00.000000" ] ],
 					"subnet[20].%[1]s": [ [ %[7]d, "2019-07-30 10:13:00.000000" ] ],
 					"subnet[20].%[2]s": [ [ %[8]d, "2019-07-30 10:13:00.000000" ] ],
 					"subnet[20].%[3]s": [ [ %[9]d, "2019-07-30 10:13:00.000000" ] ],
 					"subnet[20].pool[0].%[1]s": [ [ %[10]d, "2019-07-30 10:13:00.000000" ] ],
 					"subnet[20].pool[0].%[2]s": [ [ %[11]d, "2019-07-30 10:13:00.000000" ] ],
 					"subnet[20].pool[0].%[3]s": [ [ %[12]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[20].pool[1].%[1]s": [ [ %[13]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[20].pool[1].%[2]s": [ [ %[14]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[20].pool[1].%[3]s": [ [ %[15]d, "2019-07-30 10:13:00.000000" ] ],
 					"pkt4-ack-sent": [ [ 44, "2019-07-30 10:13:00.000000" ] ]
 				}
-			}]`, statistic4Names[0], statistic4Names[1], statistic4Names[2],
+			}]`,
+				// Labels.
+				// 1.               2.                  3.
+				statistic4Names[0], statistic4Names[1], statistic4Names[2],
+				// Subnet 10 (and pool 0).
+				// 4.           5.         6.
 				256+totalShift, 111+shift, 0+shift,
+				// Subnet 20.
+				// 7.            8.          9.
 				4098+totalShift, 2034+shift, 4+shift,
+				// Pool 0 in subnet 20.
+				// 10.         11.      12.
 				10+totalShift, 4+shift, 2+shift,
+				// Pool 1 in subnet 20.
+				// 13. 14.  15.
+				4088, 2030, 2,
 			),
 			fmt.Sprintf(`[{
 				"result": 0,
 				"arguments": {
-					"subnet[30].total-nas": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[30].assigned-nas": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[30].declined-addresses": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[30].total-pds": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[30].assigned-pds": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[40].total-nas": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[40].assigned-nas": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[40].declined-addresses": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[40].total-pds": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[40].assigned-pds": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[50].total-nas": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[50].assigned-nas": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[50].declined-addresses": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[50].total-pds": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[50].assigned-pds": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[60].total-nas": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[60].assigned-nas": [ [ %s, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[60].declined-addresses": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[60].total-pds": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[60].assigned-pds": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[50].pool[0].total-nas": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[50].pool[0].assigned-nas": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[50].pool[0].declined-addresses": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[50].pd-pool[0].total-pds": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
-					"subnet[50].pd-pool[0].assigned-pds": [ [ %d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[30].total-nas": [ [ %[1]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[30].assigned-nas": [ [ %[2]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[30].declined-addresses": [ [ %[3]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[30].total-pds": [ [ %[4]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[30].assigned-pds": [ [ %[5]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[30].pool[0].total-nas": [ [ %[1]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[30].pool[0].assigned-nas": [ [ %[2]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[30].pool[0].declined-addresses": [ [ %[3]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[30].pd-pool[0].total-pds": [ [ %[4]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[30].pd-pool[0].assigned-pds": [ [ %[5]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[40].total-nas": [ [ %[6]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[40].assigned-nas": [ [ %[7]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[40].declined-addresses": [ [ %[8]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[40].total-pds": [ [ %[9]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[40].assigned-pds": [ [ %[10]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[40].pool[0].total-nas": [ [ %[6]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[40].pool[0].assigned-nas": [ [ %[7]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[40].pool[0].declined-addresses": [ [ %[8]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[40].pd-pool[0].total-pds": [ [ %[9]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[40].pd-pool[0].assigned-pds": [ [ %[10]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[50].total-nas": [ [ %[11]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[50].assigned-nas": [ [ %[12]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[50].declined-addresses": [ [ %[13]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[50].total-pds": [ [ %[14]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[50].assigned-pds": [ [ %[15]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[60].total-nas": [ [ %[16]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[60].assigned-nas": [ [ %[17]s, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[60].declined-addresses": [ [ %[18]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[60].total-pds": [ [ %[19]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[60].assigned-pds": [ [ %[20]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[60].pool[0].total-nas": [ [ %[16]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[60].pool[0].assigned-nas": [ [ %[17]s, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[60].pool[0].declined-addresses": [ [ %[18]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[60].pd-pool[0].total-pds": [ [ %[19]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[60].pd-pool[0].assigned-pds": [ [ %[20]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[50].pool[0].total-nas": [ [ %[21]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[50].pool[0].assigned-nas": [ [ %[22]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[50].pool[0].declined-addresses": [ [ %[23]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[50].pd-pool[0].total-pds": [ [ %[24]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[50].pd-pool[0].assigned-pds": [ [ %[25]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[50].pool[1].total-nas": [ [ %[26]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[50].pool[1].assigned-nas": [ [ %[27]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[50].pool[1].declined-addresses": [ [ %[28]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[50].pd-pool[1].total-pds": [ [ %[29]d, "2019-07-30 10:13:00.000000" ] ],
+					"subnet[50].pd-pool[1].assigned-pds": [ [ %[30]d, "2019-07-30 10:13:00.000000" ] ],
 					"pkt6-reply-sent": [ [ 66, "2019-07-30 10:13:00.000000" ] ]
 				}
 			}]`,
+				// Subnet 30.
+				// 1.            2.          3.       4.            5.
 				4096+totalShift, 2400+shift, 3+shift, 0+totalShift, 0+shift,
+				// Subnet 40.
+				// 6.         7.       8.       9.               10.
 				0+totalShift, 0+shift, 0+shift, 1048+totalShift, 233+shift,
-				256+totalShift, 60+shift, 0+shift, 1048+totalShift, 15+shift,
+				// Subnet 50.
+				// 11.          12.       13.       14.              15.
+				256+totalShift, 60+shift, 10+shift, 1048+totalShift, 35+shift,
+				// Subnet 60.
+				// 16. 17.                 18. 19. 20.
 				-1, "9223372036854775807", 0, -2, -3,
+				// Address pool 0 and PD pool 0 in subnet 50.
+				// 21.         22.      23.      24.            25.
 				20+totalShift, 8+shift, 4+shift, 40+totalShift, 20+shift,
+				// Address pool 1 and PD pool 1 in subnet 50.
+				// 26.         27.      28.      29.            30.
+				234, 50, 0, 1008, 5,
 			),
 		}
 	})
@@ -136,17 +188,29 @@ func createDhcpConfigs() (string, string) {
 			"subnet4": [
 				{
 					"id": 10,
-					"subnet": "192.0.2.0/24"
+					"subnet": "192.0.2.0/24",
+					"pools": [
+						{
+							"pool": "192.0.2.1 - 192.0.2.10"
+						}
+					]
 				},
 				{
 					"id": 20,
 					"subnet": "192.0.3.0/24",
-					// 1 in-pool, 2 out-of-pool host reservations
 					"pools": [
 						{
 							"pool": "192.0.3.1 - 192.0.3.10"
+						},
+						{
+							"pool": "192.0.3.11 - 192.0.3.20"
+						},
+						{
+							"pool": "192.0.3.21 - 192.0.3.30",
+							"pool-id": 1
 						}
 					],
+					// 1 in-pool, 2 out-of-pool host reservations
 					"reservations": [
 						{
 							"hw-address": "00:00:00:00:00:21",
@@ -181,11 +245,27 @@ func createDhcpConfigs() (string, string) {
 			"subnet6": [
 				{
 					"id": 30,
-					"subnet": "2001:db8:1::/64"
+					"subnet": "2001:db8:1::/64",
+					"pools": [{
+						"pool": "2001:db8:1::100-2001:db8:1::ffff"
+					}],
+					"pd-pools": [{
+						"prefix": "2001:db8:1:8000::",
+						"prefix-len": 64,
+						"delegated-len": 80
+					}]
 				},
 				{
 					"id": 40,
-					"subnet": "2001:db8:2::/64"
+					"subnet": "2001:db8:2::/64",
+					"pools": [{
+						"pool": "2001:db8:2::100-2001:db8:2::ffff"
+					}],
+					"pd-pools": [{
+						"prefix": "2001:db8:2:8000::",
+						"prefix-len": 64,
+						"delegated-len": 80
+					}]
 				},
 				{
 					"id": 50,
@@ -193,13 +273,31 @@ func createDhcpConfigs() (string, string) {
 					"pools": [
 						{
 							"pool": "2001:db8:3::100-2001:db8:3::ffff"
+						},
+						{
+							"pool": "2001:db8:3::1:100-2001:db8:3::1:ffff"
+						},
+						{
+							"pool": "2001:db8:3::2:100-2001:db8:3::2:ffff",
+							"pool-id": 1
 						}
 					],
 					"pd-pools": [
 						{
-							"prefix": "2001:db8:3:8000::",
+							"prefix": "2001:db8:3:1:8000::",
 							"prefix-len": 64,
 							"delegated-len": 80
+						},
+						{
+							"prefix": "2001:db8:2:8000::",
+							"prefix-len": 64,
+							"delegated-len": 80
+						},
+						{
+							"prefix": "2001:db8:3:8000::",
+							"prefix-len": 64,
+							"delegated-len": 80,
+							"pool-id": 1
 						}
 					],
 					// 2 out-of-pool, 1 in-pool host reservations
@@ -252,6 +350,13 @@ func verifyStandardLocalSubnetsStatistics(t *testing.T, db *pg.DB) {
 	require.NoError(t, err)
 	snCnt := 0
 	for _, sn := range localSubnets {
+		sort.Slice(sn.AddressPools, func(i, j int) bool {
+			return sn.AddressPools[i].KeaParameters.PoolID < sn.AddressPools[j].KeaParameters.PoolID
+		})
+		sort.Slice(sn.PrefixPools, func(i, j int) bool {
+			return sn.PrefixPools[i].KeaParameters.PoolID < sn.PrefixPools[j].KeaParameters.PoolID
+		})
+
 		shift := (sn.Daemon.AppID - 1) * 100
 		totalShift := shift * 2
 		switch sn.LocalSubnetID {
@@ -267,10 +372,20 @@ func verifyStandardLocalSubnetsStatistics(t *testing.T, db *pg.DB) {
 			snCnt++
 
 			// Check pools.
-			require.Len(t, sn.AddressPools, 1)
+			require.Len(t, sn.AddressPools, 3)
+
+			require.Zero(t, sn.AddressPools[0].KeaParameters.PoolID)
 			require.Equal(t, uint64(10+totalShift), sn.AddressPools[0].Stats["total-addresses"])
 			require.Equal(t, uint64(4+shift), sn.AddressPools[0].Stats["assigned-addresses"])
 			require.Equal(t, uint64(2+shift), sn.AddressPools[0].Stats["declined-addresses"])
+			require.Zero(t, sn.AddressPools[1].KeaParameters.PoolID)
+			require.Equal(t, uint64(10+totalShift), sn.AddressPools[1].Stats["total-addresses"])
+			require.Equal(t, uint64(4+shift), sn.AddressPools[1].Stats["assigned-addresses"])
+			require.Equal(t, uint64(2+shift), sn.AddressPools[1].Stats["declined-addresses"])
+			require.EqualValues(t, 1, sn.AddressPools[2].KeaParameters.PoolID)
+			require.Equal(t, uint64(4088), sn.AddressPools[2].Stats["total-addresses"])
+			require.Equal(t, uint64(2030), sn.AddressPools[2].Stats["assigned-addresses"])
+			require.Equal(t, uint64(2), sn.AddressPools[2].Stats["declined-addresses"])
 		case 30:
 			require.Equal(t, uint64(2400+shift), sn.Stats["assigned-nas"])
 			require.Equal(t, uint64(0+shift), sn.Stats["assigned-pds"])
@@ -287,21 +402,43 @@ func verifyStandardLocalSubnetsStatistics(t *testing.T, db *pg.DB) {
 			snCnt++
 		case 50:
 			require.Equal(t, uint64(60+shift), sn.Stats["assigned-nas"])
-			require.Equal(t, uint64(15+shift), sn.Stats["assigned-pds"])
-			require.Equal(t, uint64(0+shift), sn.Stats["declined-nas"])
+			require.Equal(t, uint64(35+shift), sn.Stats["assigned-pds"])
+			require.Equal(t, uint64(10+shift), sn.Stats["declined-nas"])
 			require.Equal(t, uint64(256+totalShift), sn.Stats["total-nas"])
 			require.Equal(t, uint64(1048+totalShift), sn.Stats["total-pds"])
 			snCnt++
 
 			// Check pools.
-			require.Len(t, sn.AddressPools, 1)
+			require.Len(t, sn.AddressPools, 3)
+
+			require.Zero(t, sn.AddressPools[0].KeaParameters.PoolID)
 			require.Equal(t, uint64(20+totalShift), sn.AddressPools[0].Stats["total-nas"])
 			require.Equal(t, uint64(8+shift), sn.AddressPools[0].Stats["assigned-nas"])
 			require.Equal(t, uint64(4+shift), sn.AddressPools[0].Stats["declined-nas"])
 
-			require.Len(t, sn.PrefixPools, 1)
+			require.Zero(t, sn.AddressPools[1].KeaParameters.PoolID)
+			require.Equal(t, uint64(20+totalShift), sn.AddressPools[1].Stats["total-nas"])
+			require.Equal(t, uint64(8+shift), sn.AddressPools[1].Stats["assigned-nas"])
+			require.Equal(t, uint64(4+shift), sn.AddressPools[1].Stats["declined-nas"])
+
+			require.EqualValues(t, 1, sn.AddressPools[2].KeaParameters.PoolID)
+			require.Equal(t, uint64(234), sn.AddressPools[2].Stats["total-nas"])
+			require.Equal(t, uint64(50), sn.AddressPools[2].Stats["assigned-nas"])
+			require.Equal(t, uint64(0), sn.AddressPools[2].Stats["declined-nas"])
+
+			require.Len(t, sn.PrefixPools, 3)
+
+			require.Zero(t, sn.PrefixPools[0].KeaParameters.PoolID)
 			require.Equal(t, uint64(40+totalShift), sn.PrefixPools[0].Stats["total-pds"])
 			require.Equal(t, uint64(20+shift), sn.PrefixPools[0].Stats["assigned-pds"])
+
+			require.Zero(t, sn.PrefixPools[1].KeaParameters.PoolID)
+			require.Equal(t, uint64(40+totalShift), sn.PrefixPools[1].Stats["total-pds"])
+			require.Equal(t, uint64(20+shift), sn.PrefixPools[1].Stats["assigned-pds"])
+
+			require.EqualValues(t, 1, sn.PrefixPools[2].KeaParameters.PoolID)
+			require.Equal(t, uint64(1008), sn.PrefixPools[2].Stats["total-pds"])
+			require.Equal(t, uint64(5), sn.PrefixPools[2].Stats["assigned-pds"])
 		case 60:
 			require.Equal(t, uint64(math.MaxUint64), sn.Stats["total-nas"])
 			require.Equal(t, uint64(math.MaxInt64), sn.Stats["assigned-nas"])
@@ -435,15 +572,15 @@ func checkStatsPullerPullStats(t *testing.T, statsFormat string) {
 	verifyStandardLocalSubnetsStatistics(t, db)
 
 	// We should have two rows in RpsWorker.PreviousRps map one for each daemon
-	require.Equal(t, 2, len(sp.RpsWorker.PreviousRps))
+	require.Equal(t, 2, len(sp.PreviousRps))
 
 	// Entry for ID 1 should be dhcp4 daemon, it should have an RPS value of 44
-	previous := sp.RpsWorker.PreviousRps[1]
+	previous := sp.PreviousRps[1]
 	require.NotEqual(t, nil, previous)
 	require.EqualValues(t, 44, previous.Value)
 
 	// Entry for ID 2 should be dhcp6 daemon, it should have an RPS value of 66
-	previous = sp.RpsWorker.PreviousRps[2]
+	previous = sp.PreviousRps[2]
 	require.NotEqual(t, nil, previous)
 	require.EqualValues(t, 66, previous.Value)
 
@@ -455,18 +592,60 @@ func checkStatsPullerPullStats(t *testing.T, statsFormat string) {
 		case 10:
 			require.InDelta(t, 111.0/256.0, float64(sn.AddrUtilization), 0.001)
 			require.Zero(t, sn.PdUtilization)
+			require.EqualValues(t, 256, sn.Stats.GetBigCounter(dbmodel.StatNameTotalAddresses).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameTotalOutOfPoolAddresses).ToInt64())
+			require.EqualValues(t, 111, sn.Stats.GetBigCounter(dbmodel.StatNameAssignedAddresses).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameAssignedOutOfPoolAddresses).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameDeclinedAddresses).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameDeclinedOutOfPoolAddresses).ToInt64())
 		case 20:
 			require.InDelta(t, 2034.0/(4098.0+2), float64(sn.AddrUtilization), 0.001)
 			require.Zero(t, sn.PdUtilization)
+			require.EqualValues(t, 4100, sn.Stats.GetBigCounter(dbmodel.StatNameTotalAddresses).ToInt64())
+			require.EqualValues(t, 2, sn.Stats.GetBigCounter(dbmodel.StatNameTotalOutOfPoolAddresses).ToInt64())
+			require.EqualValues(t, 2034, sn.Stats.GetBigCounter(dbmodel.StatNameAssignedAddresses).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameAssignedOutOfPoolAddresses).ToInt64())
+			require.EqualValues(t, 4, sn.Stats.GetBigCounter(dbmodel.StatNameDeclinedAddresses).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameDeclinedOutOfPoolAddresses).ToInt64())
 		case 30:
 			require.InDelta(t, 2400.0/4096.0, float64(sn.AddrUtilization), 0.001)
 			require.Zero(t, sn.PdUtilization)
+			require.EqualValues(t, 4096, sn.Stats.GetBigCounter(dbmodel.StatNameTotalNAs).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameTotalOutOfPoolNAs).ToInt64())
+			require.EqualValues(t, 2400, sn.Stats.GetBigCounter(dbmodel.StatNameAssignedNAs).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameAssignedOutOfPoolNAs).ToInt64())
+			require.EqualValues(t, 3, sn.Stats.GetBigCounter(dbmodel.StatNameDeclinedNAs).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameDeclinedOutOfPoolNAs).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameTotalPDs).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameTotalOutOfPoolPDs).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameAssignedPDs).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameAssignedOutOfPoolPDs).ToInt64())
 		case 40:
 			require.Zero(t, sn.AddrUtilization)
 			require.InDelta(t, 233.0/1048.0, float64(sn.PdUtilization), 0.001)
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameTotalNAs).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameTotalOutOfPoolNAs).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameAssignedNAs).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameAssignedOutOfPoolNAs).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameDeclinedNAs).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameDeclinedOutOfPoolNAs).ToInt64())
+			require.EqualValues(t, 1048, sn.Stats.GetBigCounter(dbmodel.StatNameTotalPDs).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameTotalOutOfPoolPDs).ToInt64())
+			require.EqualValues(t, 233, sn.Stats.GetBigCounter(dbmodel.StatNameAssignedPDs).ToInt64())
+			require.Zero(t, sn.Stats.GetBigCounter(dbmodel.StatNameAssignedOutOfPoolPDs).ToInt64())
 		case 50:
-			require.InDelta(t, 60.0/(256.0+2), float64(sn.AddrUtilization), 0.001)
-			require.InDelta(t, 15.0/(1048.0+1), float64(sn.PdUtilization), 0.001)
+			require.InDelta(t, 60.0/(254.0+4), float64(sn.AddrUtilization), 0.001)
+			require.InDelta(t, 35.0/(1048.0+1), float64(sn.PdUtilization), 0.001)
+			require.EqualValues(t, 254+4, sn.Stats.GetBigCounter(dbmodel.StatNameTotalNAs).ToInt64())
+			require.EqualValues(t, 4, sn.Stats.GetBigCounter(dbmodel.StatNameTotalOutOfPoolNAs).ToInt64())
+			require.EqualValues(t, 60, sn.Stats.GetBigCounter(dbmodel.StatNameAssignedNAs).ToInt64())
+			require.EqualValues(t, 2, sn.Stats.GetBigCounter(dbmodel.StatNameAssignedOutOfPoolNAs).ToInt64())
+			require.EqualValues(t, 10, sn.Stats.GetBigCounter(dbmodel.StatNameDeclinedNAs).ToInt64())
+			require.EqualValues(t, 6, sn.Stats.GetBigCounter(dbmodel.StatNameDeclinedOutOfPoolNAs).ToInt64())
+			require.EqualValues(t, 1048+1, sn.Stats.GetBigCounter(dbmodel.StatNameTotalPDs).ToInt64())
+			require.EqualValues(t, 1, sn.Stats.GetBigCounter(dbmodel.StatNameTotalOutOfPoolPDs).ToInt64())
+			require.EqualValues(t, 35, sn.Stats.GetBigCounter(dbmodel.StatNameAssignedPDs).ToInt64())
+			require.EqualValues(t, 10, sn.Stats.GetBigCounter(dbmodel.StatNameAssignedOutOfPoolPDs).ToInt64())
 		}
 	}
 
@@ -482,12 +661,12 @@ func checkStatsPullerPullStats(t *testing.T, statsFormat string) {
 	require.EqualValues(t, big.NewInt(0).Add(
 		big.NewInt(2460), big.NewInt(math.MaxInt64),
 	), globals["assigned-nas"])
-	require.EqualValues(t, big.NewInt(3), globals["declined-nas"])
+	require.EqualValues(t, big.NewInt(13), globals["declined-nas"])
 	require.EqualValues(t, big.NewInt(0).Add(
 		big.NewInt(2097), big.NewInt(0).SetUint64(math.MaxUint64),
 	), globals["total-pds"])
 	require.EqualValues(t, big.NewInt(0).Add(
-		big.NewInt(246), big.NewInt(0).SetUint64(math.MaxUint64),
+		big.NewInt(266), big.NewInt(0).SetUint64(math.MaxUint64),
 	), globals["assigned-pds"])
 }
 
@@ -749,7 +928,7 @@ func verifyCountingStatisticsFromPrimary(t *testing.T, db *pg.DB) {
 			require.InDelta(t, 233.0/1048.0, float64(sn.PdUtilization), 0.001)
 		case "2001:db8:3::/64":
 			require.InDelta(t, 60.0/(256.0+2), float64(sn.AddrUtilization), 0.001)
-			require.InDelta(t, 15.0/(1048.0+1), float64(sn.PdUtilization), 0.001)
+			require.InDelta(t, 35.0/(1048.0+1), float64(sn.PdUtilization), 0.001)
 		}
 	}
 
@@ -765,12 +944,12 @@ func verifyCountingStatisticsFromPrimary(t *testing.T, db *pg.DB) {
 	require.EqualValues(t, big.NewInt(0).Add(
 		big.NewInt(2460), big.NewInt(math.MaxInt64),
 	), globals["assigned-nas"])
-	require.EqualValues(t, big.NewInt(3), globals["declined-nas"])
+	require.EqualValues(t, big.NewInt(13), globals["declined-nas"])
 	require.EqualValues(t, big.NewInt(0).Add(
 		big.NewInt(2097), big.NewInt(0).SetUint64(math.MaxUint64),
 	), globals["total-pds"])
 	require.EqualValues(t, big.NewInt(0).Add(
-		big.NewInt(246), big.NewInt(0).SetUint64(math.MaxUint64),
+		big.NewInt(266), big.NewInt(0).SetUint64(math.MaxUint64),
 	), globals["assigned-pds"])
 }
 
@@ -801,7 +980,7 @@ func verifyCountingStatisticsFromSecondary(t *testing.T, db *pg.DB) {
 			require.InDelta(t, 333.0/1248.0, float64(sn.PdUtilization), 0.001)
 		case "2001:db8:3::/64":
 			require.InDelta(t, 160.0/(456.0+2), float64(sn.AddrUtilization), 0.001)
-			require.InDelta(t, 115.0/(1248.0+1), float64(sn.PdUtilization), 0.001)
+			require.InDelta(t, 135.0/(1248.0+1), float64(sn.PdUtilization), 0.001)
 		}
 	}
 
@@ -817,12 +996,12 @@ func verifyCountingStatisticsFromSecondary(t *testing.T, db *pg.DB) {
 	require.EqualValues(t, big.NewInt(0).Add(
 		big.NewInt(2760), big.NewInt(math.MaxInt64),
 	), globals["assigned-nas"])
-	require.EqualValues(t, big.NewInt(303), globals["declined-nas"])
+	require.EqualValues(t, big.NewInt(313), globals["declined-nas"])
 	require.EqualValues(t, big.NewInt(0).Add(
 		big.NewInt(2697), big.NewInt(0).SetUint64(math.MaxUint64),
 	), globals["total-pds"])
 	require.EqualValues(t, big.NewInt(0).Add(
-		big.NewInt(546), big.NewInt(0).SetUint64(math.MaxUint64),
+		big.NewInt(566), big.NewInt(0).SetUint64(math.MaxUint64),
 	), globals["assigned-pds"])
 }
 
