@@ -19,9 +19,9 @@ func init() {
             ALTER TABLE ha_service ADD COLUMN IF NOT EXISTS secondary_unacked_clients_left bigint;
             ALTER TABLE ha_service ADD COLUMN IF NOT EXISTS secondary_analyzed_packets bigint;
 
-            -- Trigger function invoked upon deletion of an association between
-            -- daemons and service. It removes the service if this service has no
-            -- more associations with any daemon.
+            -- This trigger function is invoked upon deletion of an association between
+            -- daemons and services. It removes a service if it no longer has
+            -- associations with any daemon.
             CREATE OR REPLACE FUNCTION wipe_dangling_service()
                 RETURNS trigger
                 LANGUAGE 'plpgsql'
@@ -36,8 +36,8 @@ func init() {
             END;
             $function$;
 
-            -- Trigger which removes a service which no longer has any associations
-            -- with daemons.
+            -- This trigger removes a service that no longer has associations
+            -- with any daemons.
             DO $$ BEGIN
                 CREATE TRIGGER trigger_wipe_dangling_service
                     AFTER DELETE ON daemon_to_service
