@@ -64,18 +64,27 @@ func TestFilledSubnetsDatabaseMetrics(t *testing.T) {
 	// Arrange
 	db, _, teardown := dbtest.SetupDatabaseTestCase(t)
 	defer teardown()
+
 	_ = AddSubnet(db, &Subnet{
 		Prefix:          "3001:1::/64",
-		AddrUtilization: 10,
-		PdUtilization:   15,
+		AddrUtilization: Utilization(0.10),
+		PdUtilization:   Utilization(0.15),
+	})
+	_ = AddSharedNetwork(db, &SharedNetwork{
+		Name:   "alice",
+		Family: 6,
+		Subnets: []Subnet{
+			{
+				Prefix:          "3001:2::/64",
+				AddrUtilization: Utilization(0.20),
+				PdUtilization:   Utilization(0.25),
+			},
+		},
 	})
 	_ = AddSubnet(db, &Subnet{
-		Prefix:          "3001:2::/64",
-		AddrUtilization: 20,
-		PdUtilization:   25,
-	})
-	_ = AddSubnet(db, &Subnet{
-		Prefix: "192.168.2.1/32",
+		Prefix:          "192.168.2.1/32",
+		AddrUtilization: Utilization(0.0),
+		PdUtilization:   Utilization(0.0),
 	})
 
 	// Act
@@ -85,17 +94,20 @@ func TestFilledSubnetsDatabaseMetrics(t *testing.T) {
 	require.NoError(t, err)
 	require.Len(t, metrics.SubnetMetrics, 3)
 
-	require.EqualValues(t, "3001:1::/64", metrics.SubnetMetrics[0].Label)
-	require.EqualValues(t, 10, metrics.SubnetMetrics[0].AddrUtilization)
-	require.EqualValues(t, 15, metrics.SubnetMetrics[0].PdUtilization)
+	require.EqualValues(t, "3001:1::/64", metrics.SubnetMetrics[0].Prefix)
+	require.Empty(t, metrics.SubnetMetrics[0].SharedNetwork)
+	require.EqualValues(t, 0.1, metrics.SubnetMetrics[0].AddrUtilization)
+	require.EqualValues(t, 0.15, metrics.SubnetMetrics[0].PdUtilization)
 	require.EqualValues(t, 6, metrics.SubnetMetrics[0].Family)
 
-	require.EqualValues(t, "3001:2::/64", metrics.SubnetMetrics[1].Label)
-	require.EqualValues(t, 20, metrics.SubnetMetrics[1].AddrUtilization)
-	require.EqualValues(t, 25, metrics.SubnetMetrics[1].PdUtilization)
+	require.EqualValues(t, "3001:2::/64", metrics.SubnetMetrics[1].Prefix)
+	require.Equal(t, "alice", metrics.SubnetMetrics[1].SharedNetwork)
+	require.EqualValues(t, 0.20, metrics.SubnetMetrics[1].AddrUtilization)
+	require.EqualValues(t, 0.25, metrics.SubnetMetrics[1].PdUtilization)
 	require.EqualValues(t, 6, metrics.SubnetMetrics[1].Family)
 
-	require.EqualValues(t, "192.168.2.1/32", metrics.SubnetMetrics[2].Label)
+	require.EqualValues(t, "192.168.2.1/32", metrics.SubnetMetrics[2].Prefix)
+	require.Empty(t, metrics.SubnetMetrics[2].SharedNetwork)
 	require.Zero(t, metrics.SubnetMetrics[2].AddrUtilization)
 	require.Zero(t, metrics.SubnetMetrics[2].PdUtilization)
 	require.EqualValues(t, 4, metrics.SubnetMetrics[2].Family)
@@ -112,20 +124,20 @@ func TestFilledSharedNetworksDatabaseMetrics(t *testing.T) {
 	// present in the previous implementation.
 	_ = AddSharedNetwork(db, &SharedNetwork{
 		Name:            "alice",
-		AddrUtilization: 10,
-		PdUtilization:   15,
+		AddrUtilization: 0.10,
+		PdUtilization:   0.15,
 		Family:          4,
 	})
 	_ = AddSharedNetwork(db, &SharedNetwork{
 		Name:            "alice",
-		AddrUtilization: 5,
-		PdUtilization:   30,
+		AddrUtilization: 0.05,
+		PdUtilization:   0.30,
 		Family:          6,
 	})
 	_ = AddSharedNetwork(db, &SharedNetwork{
 		Name:            "bob",
-		AddrUtilization: 20,
-		PdUtilization:   25,
+		AddrUtilization: 0.20,
+		PdUtilization:   0.25,
 		Family:          4,
 	})
 	_ = AddSharedNetwork(db, &SharedNetwork{
@@ -140,22 +152,26 @@ func TestFilledSharedNetworksDatabaseMetrics(t *testing.T) {
 	require.NoError(t, err)
 	require.Len(t, metrics.SharedNetworkMetrics, 4)
 
-	require.EqualValues(t, "alice", metrics.SharedNetworkMetrics[0].Label)
-	require.EqualValues(t, 10, metrics.SharedNetworkMetrics[0].AddrUtilization)
-	require.EqualValues(t, 15, metrics.SharedNetworkMetrics[0].PdUtilization)
+	require.Empty(t, metrics.SharedNetworkMetrics[0].Prefix)
+	require.EqualValues(t, "alice", metrics.SharedNetworkMetrics[0].SharedNetwork)
+	require.EqualValues(t, 0.1, float64(metrics.SharedNetworkMetrics[0].AddrUtilization))
+	require.EqualValues(t, 0.15, float64(metrics.SharedNetworkMetrics[0].PdUtilization))
 	require.EqualValues(t, 4, metrics.SharedNetworkMetrics[0].Family)
 
-	require.EqualValues(t, "alice", metrics.SharedNetworkMetrics[1].Label)
-	require.EqualValues(t, 5, metrics.SharedNetworkMetrics[1].AddrUtilization)
-	require.EqualValues(t, 30, metrics.SharedNetworkMetrics[1].PdUtilization)
+	require.Empty(t, metrics.SharedNetworkMetrics[1].Prefix)
+	require.EqualValues(t, "alice", metrics.SharedNetworkMetrics[1].SharedNetwork)
+	require.EqualValues(t, 0.05, float64(metrics.SharedNetworkMetrics[1].AddrUtilization))
+	require.EqualValues(t, 0.30, float64(metrics.SharedNetworkMetrics[1].PdUtilization))
 	require.EqualValues(t, 6, metrics.SharedNetworkMetrics[1].Family)
 
-	require.EqualValues(t, "bob", metrics.SharedNetworkMetrics[2].Label)
-	require.EqualValues(t, 20, metrics.SharedNetworkMetrics[2].AddrUtilization)
-	require.EqualValues(t, 25, metrics.SharedNetworkMetrics[2].PdUtilization)
+	require.Empty(t, metrics.SharedNetworkMetrics[2].Prefix)
+	require.EqualValues(t, "bob", metrics.SharedNetworkMetrics[2].SharedNetwork)
+	require.EqualValues(t, 0.20, float64(metrics.SharedNetworkMetrics[2].AddrUtilization))
+	require.EqualValues(t, 0.25, float64(metrics.SharedNetworkMetrics[2].PdUtilization))
 	require.EqualValues(t, 4, metrics.SharedNetworkMetrics[2].Family)
 
-	require.EqualValues(t, "eva", metrics.SharedNetworkMetrics[3].Label)
+	require.Empty(t, metrics.SharedNetworkMetrics[3].Prefix)
+	require.EqualValues(t, "eva", metrics.SharedNetworkMetrics[3].SharedNetwork)
 	require.Zero(t, metrics.SharedNetworkMetrics[3].AddrUtilization)
 	require.Zero(t, metrics.SharedNetworkMetrics[3].PdUtilization)
 	require.EqualValues(t, 6, metrics.SharedNetworkMetrics[3].Family)
