@@ -81,6 +81,22 @@ func InitializeSettings(db *pg.DB, initialPullerInterval int64) error {
 			ValType: SettingValTypeStr,
 			Value:   "",
 		},
+		{
+			Name:    "grafana_dhcp4_dashboard_id",
+			ValType: SettingValTypeStr,
+			// This value corresponds to the UID of the dashboard in the
+			// Grafana configuration. It is defined in the
+			// "/grafana/kea-dhcp4.json" file.
+			Value: "hRf18FvWz",
+		},
+		{
+			Name:    "grafana_dhcp6_dashboard_id",
+			ValType: SettingValTypeStr,
+			// This value corresponds to the UID of the dashboard in the
+			// Grafana configuration. It is defined in the
+			// "/grafana/kea-dhcp6.json" file.
+			Value: "AQPHKJUGz",
+		},
 		{
 			Name:    "enable_machine_registration",
 			ValType: SettingValTypeBool,
