@@ -541,6 +541,25 @@ func (r *RestAPI) CreateMachine(ctx context.Context, params services.CreateMachi
 		return rsp
 	}
 
+	serverCertPEM, err := dbmodel.GetSecret(r.DB, dbmodel.SecretServerCert)
+	if err != nil {
+		msg := "Problem loading server cert"
+		log.WithError(err).Error(msg)
+		rsp := services.NewCreateMachineDefault(http.StatusInternalServerError).WithPayload(&models.APIError{
+			Message: &msg,
+		})
+		return rsp
+	}
+	serverCertFingerprint, err := pki.CalculateFingerprintFromPEM(serverCertPEM)
+	if err != nil {
+		msg := "Problem calculating fingerprint of server cert"
+		log.WithError(err).Error(msg)
+		rsp := services.NewCreateMachineDefault(http.StatusInternalServerError).WithPayload(&models.APIError{
+			Message: &msg,
+		})
+		return rsp
+	}
+
 	machineAuthorized := false
 
 	// Check if a machine is already registered with a provided agent token
@@ -577,7 +596,12 @@ func (r *RestAPI) CreateMachine(ctx context.Context, params services.CreateMachi
 
 		if rootCertFingerprint == caCertFingerprint {
 			link := fmt.Sprintf("/machines/%d", dbMachine.ID)
-			rsp := services.NewCreateMachineConflict().WithLocation(link)
+			rsp := services.NewCreateMachineConflict().
+				WithLocation(link).
+				WithPayload(&models.ExistingMachineResp{
+					ID:                    dbMachine.ID,
+					ServerCertFingerprint: storkutil.BytesToHex(serverCertFingerprint[:]),
+				})
 			return rsp
 		}
 
@@ -642,25 +666,6 @@ func (r *RestAPI) CreateMachine(ctx context.Context, params services.CreateMachi
 		return rsp
 	}
 
-	serverCertPEM, err := dbmodel.GetSecret(r.DB, dbmodel.SecretServerCert)
-	if err != nil {
-		msg := "Problem loading server cert"
-		log.WithError(err).Error(msg)
-		rsp := services.NewCreateMachineDefault(http.StatusInternalServerError).WithPayload(&models.APIError{
-			Message: &msg,
-		})
-		return rsp
-	}
-	serverCertFingerprint, err := pki.CalculateFingerprintFromPEM(serverCertPEM)
-	if err != nil {
-		msg := "Problem calculating fingerprint of server cert"
-		log.WithError(err).Error(msg)
-		rsp := services.NewCreateMachineDefault(http.StatusInternalServerError).WithPayload(&models.APIError{
-			Message: &msg,
-		})
-		return rsp
-	}
-
 	// We can't create new machine and pull machines' states at the same time. This may
 	// put heavy workload on the server and it may also result in conflicts. Temporarily
 	// disable the puller while the new machine is being added.
