@@ -157,7 +157,7 @@ func (r *RestAPI) CreateSession(ctx context.Context, params users.CreateSessionP
 	var err error
 
 	if params.Credentials == nil {
-		log.Warning(("Cannot authenticate a user due to missing credentials"))
+		log.Debug(("Cannot authenticate a user due to missing credentials"))
 		return users.NewCreateSessionBadRequest()
 	}
 
@@ -179,14 +179,14 @@ func (r *RestAPI) CreateSession(ctx context.Context, params users.CreateSessionP
 		log.
 			WithField("method", authenticationMethod).
 			WithField("identifier", *params.Credentials.Identifier).
-			Error("User not found, cannot authenticate")
+			Debug("User not found, cannot authenticate")
 		return users.NewCreateSessionBadRequest()
 	} else if err != nil {
 		log.
 			WithError(err).
 			WithField("method", authenticationMethod).
 			WithField("identifier", *params.Credentials.Identifier).
-			Error("Cannot authenticate a user")
+			Debug("Cannot authenticate a user")
 		return users.NewCreateSessionBadRequest()
 	}
 
@@ -195,7 +195,7 @@ func (r *RestAPI) CreateSession(ctx context.Context, params users.CreateSessionP
 		log.
 			WithError(err).
 			WithField("identifier", *params.Credentials.Identifier).
-			Error("Cannot log in a user")
+			Debug("Cannot log in a user")
 		return users.NewCreateSessionBadRequest()
 	}
 
