@@ -40,6 +40,7 @@ func AddTestHosts(t *testing.T, db *pg.DB) (hosts []dbmodel.Host, apps []dbmodel
 				dbmodel.NewKeaDaemon(dbmodel.DaemonNameDHCPv6, true),
 			},
 		}
+
 		err = a.Daemons[0].SetConfigFromJSON(`{
             "Dhcp4": {
 				"client-classes": [
@@ -126,9 +127,9 @@ func AddTestHosts(t *testing.T, db *pg.DB) (hosts []dbmodel.Host, apps []dbmodel
 
 	hasher := keaconfig.NewHasher()
 	hosts = []dbmodel.Host{
+		// Host 0.
 		{
 			SubnetID: 1,
-			Hostname: "first.example.org",
 			HostIdentifiers: []dbmodel.HostIdentifier{
 				{
 					Type:  "hw-address",
@@ -139,31 +140,42 @@ func AddTestHosts(t *testing.T, db *pg.DB) (hosts []dbmodel.Host, apps []dbmodel
 					Value: []byte{1, 2, 3, 4},
 				},
 			},
-			IPReservations: []dbmodel.IPReservation{
-				{
-					Address: "192.0.2.4",
-				},
-				{
-					Address: "192.0.2.5",
-				},
-			},
 			LocalHosts: []dbmodel.LocalHost{
 				{
 					DaemonID:       apps[0].Daemons[0].ID,
+					Hostname:       "first.example.org",
 					DataSource:     dbmodel.HostDataSourceAPI,
 					NextServer:     "192.2.2.2",
 					ServerHostname: "stork.example.org",
 					BootFileName:   "/tmp/boot.xyz",
+					IPReservations: []dbmodel.IPReservation{
+						{
+							Address: "192.0.2.4",
+						},
+						{
+							Address: "192.0.2.5",
+						},
+					},
 				},
 				{
 					DaemonID:       apps[1].Daemons[0].ID,
+					Hostname:       "first.example.org",
 					DataSource:     dbmodel.HostDataSourceAPI,
 					NextServer:     "192.2.2.2",
 					ServerHostname: "stork.example.org",
 					BootFileName:   "/tmp/boot.xyz",
+					IPReservations: []dbmodel.IPReservation{
+						{
+							Address: "192.0.2.4",
+						},
+						{
+							Address: "192.0.2.5",
+						},
+					},
 				},
 			},
 		},
+		// Host 1.
 		{
 			HostIdentifiers: []dbmodel.HostIdentifier{
 				{
@@ -175,25 +187,34 @@ func AddTestHosts(t *testing.T, db *pg.DB) (hosts []dbmodel.Host, apps []dbmodel
 					Value: []byte{2, 3, 4, 5},
 				},
 			},
-			IPReservations: []dbmodel.IPReservation{
-				{
-					Address: "192.0.2.6",
-				},
-				{
-					Address: "192.0.2.7",
-				},
-			},
 			LocalHosts: []dbmodel.LocalHost{
 				{
 					DaemonID:   apps[0].Daemons[0].ID,
-					DataSource: dbmodel.HostDataSourceAPI,
+					DataSource: dbmodel.HostDataSourceConfig,
+					IPReservations: []dbmodel.IPReservation{
+						{
+							Address: "192.0.2.6",
+						},
+						{
+							Address: "192.0.2.7",
+						},
+					},
 				},
 				{
 					DaemonID:   apps[1].Daemons[0].ID,
 					DataSource: dbmodel.HostDataSourceAPI,
+					IPReservations: []dbmodel.IPReservation{
+						{
+							Address: "192.0.2.6",
+						},
+						{
+							Address: "192.0.2.7",
+						},
+					},
 				},
 			},
 		},
+		// Host 2.
 		{
 			SubnetID: 2,
 			HostIdentifiers: []dbmodel.HostIdentifier{
@@ -202,22 +223,28 @@ func AddTestHosts(t *testing.T, db *pg.DB) (hosts []dbmodel.Host, apps []dbmodel
 					Value: []byte{1, 2, 3, 4, 5, 6},
 				},
 			},
-			IPReservations: []dbmodel.IPReservation{
-				{
-					Address: "2001:db8:1::1",
-				},
-			},
 			LocalHosts: []dbmodel.LocalHost{
 				{
 					DaemonID:   apps[0].Daemons[1].ID,
-					DataSource: dbmodel.HostDataSourceAPI,
+					DataSource: dbmodel.HostDataSourceConfig,
+					IPReservations: []dbmodel.IPReservation{
+						{
+							Address: "2001:db8:1::1",
+						},
+					},
 				},
 				{
 					DaemonID:   apps[1].Daemons[1].ID,
 					DataSource: dbmodel.HostDataSourceAPI,
+					IPReservations: []dbmodel.IPReservation{
+						{
+							Address: "2001:db8:1::1",
+						},
+					},
 				},
 			},
 		},
+		// Host 3.
 		{
 			HostIdentifiers: []dbmodel.HostIdentifier{
 				{
@@ -225,22 +252,34 @@ func AddTestHosts(t *testing.T, db *pg.DB) (hosts []dbmodel.Host, apps []dbmodel
 					Value: []byte{1, 2, 3, 4},
 				},
 			},
-			IPReservations: []dbmodel.IPReservation{
-				{
-					Address: "2001:db8:1::2",
-				},
-			},
 			LocalHosts: []dbmodel.LocalHost{
 				{
 					DaemonID:   apps[0].Daemons[1].ID,
-					DataSource: dbmodel.HostDataSourceAPI,
+					DataSource: dbmodel.HostDataSourceConfig,
+					IPReservations: []dbmodel.IPReservation{
+						{
+							Address: "2001:db8:1::2",
+						},
+						{
+							Address: "3001::/48",
+						},
+					},
 				},
 				{
 					DaemonID:   apps[1].Daemons[1].ID,
 					DataSource: dbmodel.HostDataSourceAPI,
+					IPReservations: []dbmodel.IPReservation{
+						{
+							Address: "2001:db8:1::2",
+						},
+						{
+							Address: "3001::/48",
+						},
+					},
 				},
 			},
 		},
+		// Host 4.
 		{
 			HostIdentifiers: []dbmodel.HostIdentifier{
 				{
@@ -248,15 +287,10 @@ func AddTestHosts(t *testing.T, db *pg.DB) (hosts []dbmodel.Host, apps []dbmodel
 					Value: []byte{2, 2, 2, 2},
 				},
 			},
-			IPReservations: []dbmodel.IPReservation{
-				{
-					Address: "3000::/48",
-				},
-			},
 			LocalHosts: []dbmodel.LocalHost{
 				{
 					DaemonID:   apps[0].Daemons[1].ID,
-					DataSource: dbmodel.HostDataSourceAPI,
+					DataSource: dbmodel.HostDataSourceConfig,
 					ClientClasses: []string{
 						"foo",
 						"bar",
@@ -279,6 +313,11 @@ func AddTestHosts(t *testing.T, db *pg.DB) (hosts []dbmodel.Host, apps []dbmodel
 							Universe: storkutil.IPv6,
 						},
 					}, hasher),
+					IPReservations: []dbmodel.IPReservation{
+						{
+							Address: "3000::/48",
+						},
+					},
 				},
 				{
 					DaemonID:   apps[1].Daemons[1].ID,
@@ -305,6 +344,11 @@ func AddTestHosts(t *testing.T, db *pg.DB) (hosts []dbmodel.Host, apps []dbmodel
 							Universe: storkutil.IPv6,
 						},
 					}, hasher),
+					IPReservations: []dbmodel.IPReservation{
+						{
+							Address: "3000::/48",
+						},
+					},
 				},
 			},
 		},
