@@ -1,3 +1,4 @@
+# pylint: disable=too-many-lines
 from unittest.mock import MagicMock, patch
 
 import pytest
@@ -257,6 +258,21 @@ def test_down_calls_proper_command_and_removes_volumes():
     assert cmd[-1] == "-v"
 
 
+def test_kill_calls_proper_command():
+    # Arrange
+    compose = DockerCompose("project-dir")
+    mock = MagicMock()
+    compose._call_command = mock
+    base_cmd = compose.docker_compose_command()
+    # Act
+    compose.kill()
+    # Assert
+    mock.assert_called_once()
+    cmd = mock.call_args.kwargs["cmd"]
+    assert " ".join(cmd[:-1]) == " ".join(base_cmd)
+    assert cmd[-1] == "kill"
+
+
 def test_run_calls_proper_command():
     # Arrange
     compose = DockerCompose("project-dir")
@@ -881,6 +897,53 @@ def test_get_build_arguments():
     assert args == {"bar": "baz", "biz": 42}
 
 
+def test_get_configured_environment_variables_no_env():
+    # Arrange
+    compose = DockerCompose("project-dir")
+    mock = MagicMock()
+    config = {"services": {"foo": {}}}
+    config_yaml = yaml.safe_dump(config)
+    mock.return_value = (0, config_yaml, "")
+    compose._call_command = mock
+    # Act & Assert
+    assert compose.get_configured_environment_variables("foo") == {}
+
+
+def test_get_configured_environment_variables_no_service():
+    # Arrange
+    compose = DockerCompose("project-dir")
+    mock = MagicMock()
+    config = {"services": {}}
+    config_yaml = yaml.safe_dump(config)
+    mock.return_value = (0, config_yaml, "")
+    compose._call_command = mock
+    # Act & Assert
+    assert compose.get_configured_environment_variables("foo") == {}
+
+
+def test_get_configured_environment_variables():
+    # Arrange
+    compose = DockerCompose("project-dir")
+    mock = MagicMock()
+    config = {
+        "services": {
+            "foo": {
+                "environment": {
+                    "bar": "baz",
+                    "biz": 42,
+                }
+            }
+        }
+    }
+    config_yaml = yaml.safe_dump(config)
+    mock.return_value = (0, config_yaml, "")
+    compose._call_command = mock
+    # Act
+    env_vars = compose.get_configured_environment_variables("foo")
+    # Assert
+    assert env_vars == {"bar": "baz", "biz": 42}
+
+
 @patch("subprocess.run")
 def test_call_command_passes_command(subprocess_run_mock: MagicMock):
     compose = DockerCompose("project-dir")
