@@ -13,16 +13,13 @@ import { ButtonModule } from 'primeng/button'
 import { MenubarModule } from 'primeng/menubar'
 import { PanelModule } from 'primeng/panel'
 import { TableModule } from 'primeng/table'
-import { TabViewModule } from 'primeng/tabview'
 import { ProgressBarModule } from 'primeng/progressbar'
 import { DialogModule } from 'primeng/dialog'
 import { InputTextModule } from 'primeng/inputtext'
-import { DropdownModule } from 'primeng/dropdown'
+import { SelectModule } from 'primeng/select'
 import { ConfirmationService, MessageService } from 'primeng/api'
 import { ToastModule } from 'primeng/toast'
 import { MessageModule } from 'primeng/message'
-import { MessagesModule } from 'primeng/messages'
-import { TabMenuModule } from 'primeng/tabmenu'
 import { MenuModule } from 'primeng/menu'
 import { ChipModule } from 'primeng/chip'
 import { ProgressSpinnerModule } from 'primeng/progressspinner'
@@ -31,8 +28,8 @@ import { PasswordModule } from 'primeng/password'
 import { CardModule } from 'primeng/card'
 import { SplitButtonModule } from 'primeng/splitbutton'
 import { FieldsetModule } from 'primeng/fieldset'
-import { OverlayPanelModule } from 'primeng/overlaypanel'
-import { InputSwitchModule } from 'primeng/inputswitch'
+import { PopoverModule } from 'primeng/popover'
+import { ToggleSwitchModule } from 'primeng/toggleswitch'
 import { BreadcrumbModule } from 'primeng/breadcrumb'
 import { PaginatorModule } from 'primeng/paginator'
 import { SelectButtonModule } from 'primeng/selectbutton'
@@ -42,16 +39,21 @@ import { ToggleButtonModule } from 'primeng/togglebutton'
 import { MultiSelectModule } from 'primeng/multiselect'
 import { CheckboxModule } from 'primeng/checkbox'
 import { ConfirmDialogModule } from 'primeng/confirmdialog'
-import { InputTextareaModule } from 'primeng/inputtextarea'
+import { TextareaModule } from 'primeng/textarea'
 import { TreeModule } from 'primeng/tree'
 import { DataViewModule } from 'primeng/dataview'
 import { ChartModule } from 'primeng/chart'
-import { TriStateCheckboxModule } from 'primeng/tristatecheckbox'
 import { AccordionModule } from 'primeng/accordion'
 import { TreeTableModule } from 'primeng/treetable'
 import { SkeletonModule } from 'primeng/skeleton'
 import { FloatLabelModule } from 'primeng/floatlabel'
 import { AutoCompleteModule } from 'primeng/autocomplete'
+import { InputNumberModule } from 'primeng/inputnumber'
+import Aura from '@primeng/themes/aura'
+import { definePreset } from '@primeng/themes'
+import { providePrimeNG } from 'primeng/config'
+import { IconField } from 'primeng/iconfield'
+import { InputIcon } from 'primeng/inputicon'
 
 // Generated API modules
 import { ApiModule, BASE_PATH, Configuration, ConfigurationParameters } from './backend'
@@ -59,7 +61,7 @@ import { ApiModule, BASE_PATH, Configuration, ConfigurationParameters } from './
 // Stork modules
 import { environment } from './../environments/environment'
 import { getBaseApiPath } from './utils'
-import { AppRoutingModule, CustomRouteReuseStrategy } from './app-routing.module'
+import { AppRoutingModule } from './app-routing.module'
 import { AppComponent } from './app.component'
 import { AuthInterceptor } from './auth-interceptor'
 import { LoginScreenComponent } from './login-screen/login-screen.component'
@@ -130,7 +132,6 @@ import { AddressPoolFormComponent } from './address-pool-form/address-pool-form.
 import { PrefixPoolFormComponent } from './prefix-pool-form/prefix-pool-form.component'
 import { ArrayValueSetFormComponent } from './array-value-set-form/array-value-set-form.component'
 import { PriorityErrorsPanelComponent } from './priority-errors-panel/priority-errors-panel.component'
-import { RouteReuseStrategy } from '@angular/router'
 import { SharedNetworkFormComponent } from './shared-network-form/shared-network-form.component'
 import { CommunicationStatusTreeComponent } from './communication-status-tree/communication-status-tree.component'
 import { CommunicationStatusPageComponent } from './communication-status-page/communication-status-page.component'
@@ -164,6 +165,9 @@ import { OutOfPoolBarComponent } from './out-of-pool-bar/out-of-pool-bar.compone
 import { DaemonNiceNamePipe } from './pipes/daemon-name.pipe'
 import { Bind9DaemonComponent } from './bind9-daemon/bind9-daemon.component'
 import { PdnsDaemonComponent } from './pdns-daemon/pdns-daemon.component'
+import { TabViewComponent } from './tab-view/tab-view.component'
+import { TriStateCheckboxComponent } from './tri-state-checkbox/tri-state-checkbox.component'
+import { UserFormComponent } from './user-form/user-form.component'
 
 /** Create the OpenAPI client configuration. */
 export function cfgFactory() {
@@ -174,6 +178,133 @@ export function cfgFactory() {
     return new Configuration(params)
 }
 
+const AuraBluePreset = definePreset(Aura, {
+    semantic: {
+        primary: {
+            50: '{blue.50}',
+            100: '{blue.100}',
+            200: '{blue.200}',
+            300: '{blue.300}',
+            400: '{blue.400}',
+            500: '{blue.500}',
+            600: '{blue.600}',
+            700: '{blue.700}',
+            800: '{blue.800}',
+            900: '{blue.900}',
+            950: '{blue.950}',
+        },
+        colorScheme: {
+            // Adding custom 'inverted' color scheme which mimics old PrimeNG 'surface' color scheme,
+            // which for light scheme was changing from white to dark colors, and for
+            // dark scheme it was changing from dark colors to white.
+            // In new PrimeNG (v18 and following), the 'surface' color scheme behaves similarly for both light and dark mode,
+            // i.e. it changes from white to darker colors.
+            dark: {
+                inverted: {
+                    0: '{zinc.900}',
+                    50: '{zinc.800}',
+                    100: '{zinc.700}',
+                    200: '{zinc.600}',
+                    300: '{zinc.500}',
+                    400: '{zinc.400}',
+                    500: '{zinc.300}',
+                    600: '{zinc.200}',
+                    700: '{zinc.100}',
+                    800: '{zinc.50}',
+                    900: '#ffffff',
+                    950: '#ffffff',
+                },
+            },
+            light: {
+                inverted: {
+                    0: '#ffffff',
+                    50: '{slate.50}',
+                    100: '{slate.100}',
+                    200: '{slate.200}',
+                    300: '{slate.300}',
+                    400: '{slate.400}',
+                    500: '{slate.500}',
+                    600: '{slate.600}',
+                    700: '{slate.700}',
+                    800: '{slate.800}',
+                    900: '{slate.900}',
+                    950: '{slate.950}',
+                },
+            },
+        },
+    },
+    components: {
+        // Apply primary background color for Chips instead of the default greyish surface color.
+        chip: {
+            colorScheme: {
+                light: {
+                    root: {
+                        background: '{primary.100}',
+                    },
+                },
+                dark: {
+                    root: {
+                        background: '{primary.400}',
+                    },
+                },
+            },
+        },
+        // Make messages text lighter (500 by default).
+        message: {
+            colorScheme: {
+                light: {
+                    root: {
+                        textFontWeight: '400',
+                    },
+                },
+                dark: {
+                    root: {
+                        textFontWeight: '400',
+                    },
+                },
+            },
+        },
+        // Apply regular padding for all panel headers.
+        panel: {
+            colorScheme: {
+                light: {
+                    root: {
+                        toggleableHeaderPadding: '1.125rem',
+                    },
+                },
+                dark: {
+                    root: {
+                        toggleableHeaderPadding: '1.125rem',
+                    },
+                },
+            },
+        },
+        // Customize accordion header background colors and apply smaller padding for accordion panel content.
+        accordion: {
+            colorScheme: {
+                light: {
+                    root: {
+                        headerBackground: '{surface.50}',
+                        headerActiveBackground: '{surface.50}',
+                        headerHoverBackground: '{surface.100}',
+                        headerActiveHoverBackground: '{surface.100}',
+                        contentPadding: '0 0.5rem 0.5rem 0.5rem',
+                    },
+                },
+                dark: {
+                    root: {
+                        headerBackground: '{surface.950}',
+                        headerActiveBackground: '{surface.950}',
+                        headerHoverBackground: '{surface.800}',
+                        headerActiveHoverBackground: '{surface.800}',
+                        contentPadding: '0 0.5rem 0.5rem 0.5rem',
+                    },
+                },
+            },
+        },
+    },
+})
+
 @NgModule({
     declarations: [
         AppComponent,
@@ -290,15 +421,12 @@ export function cfgFactory() {
         MenubarModule,
         PanelModule,
         TableModule,
-        TabViewModule,
         ProgressBarModule,
         DialogModule,
         InputTextModule,
-        DropdownModule,
+        SelectModule,
         ToastModule,
         MessageModule,
-        MessagesModule,
-        TabMenuModule,
         MenuModule,
         ProgressSpinnerModule,
         TooltipModule,
@@ -306,8 +434,8 @@ export function cfgFactory() {
         CardModule,
         SplitButtonModule,
         FieldsetModule,
-        OverlayPanelModule,
-        InputSwitchModule,
+        PopoverModule,
+        ToggleSwitchModule,
         BreadcrumbModule,
         PaginatorModule,
         SelectButtonModule,
@@ -317,13 +445,12 @@ export function cfgFactory() {
         MultiSelectModule,
         CheckboxModule,
         ConfirmDialogModule,
-        InputTextareaModule,
+        TextareaModule,
         TreeModule,
         ChipModule,
         DataViewModule,
         ToggleButtonModule,
         ChartModule,
-        TriStateCheckboxModule,
         AccordionModule,
         TreeTableModule,
         BadgeModule,
@@ -331,6 +458,12 @@ export function cfgFactory() {
         ManagedAccessDirective,
         FloatLabelModule,
         AutoCompleteModule,
+        InputNumberModule,
+        TabViewComponent,
+        IconField,
+        InputIcon,
+        TriStateCheckboxComponent,
+        UserFormComponent,
     ],
     providers: [
         {
@@ -344,11 +477,21 @@ export function cfgFactory() {
         },
         ConfirmationService,
         MessageService,
-        {
-            provide: RouteReuseStrategy,
-            useClass: CustomRouteReuseStrategy,
-        },
         provideHttpClient(withInterceptorsFromDi()),
+        providePrimeNG({
+            theme: {
+                preset: AuraBluePreset,
+                options: {
+                    darkModeSelector: '.dark',
+                    cssLayer: {
+                        name: 'primeng',
+                        order: 'low, primeng, high',
+                    },
+                },
+            },
+        }),
     ],
 })
 export class AppModule {}
+
+export default AuraBluePreset
