@@ -2,9 +2,10 @@ import { ComponentFixture, TestBed, waitForAsync } from '@angular/core/testing'
 import { BreadcrumbsComponent } from './breadcrumbs.component'
 import { BreadcrumbModule } from 'primeng/breadcrumb'
 import { HelpTipComponent } from '../help-tip/help-tip.component'
-import { OverlayPanelModule } from 'primeng/overlaypanel'
+import { PopoverModule } from 'primeng/popover'
 import { NoopAnimationsModule } from '@angular/platform-browser/animations'
 import { provideRouter, RouterModule } from '@angular/router'
+import { ButtonModule } from 'primeng/button'
 
 describe('BreadcrumbsComponent', () => {
     let component: BreadcrumbsComponent
@@ -12,7 +13,7 @@ describe('BreadcrumbsComponent', () => {
 
     beforeEach(waitForAsync(() => {
         TestBed.configureTestingModule({
-            imports: [RouterModule, BreadcrumbModule, OverlayPanelModule, NoopAnimationsModule],
+            imports: [RouterModule, BreadcrumbModule, PopoverModule, NoopAnimationsModule, ButtonModule],
             declarations: [BreadcrumbsComponent, HelpTipComponent],
             providers: [provideRouter([])],
         }).compileComponents()
