@@ -13,7 +13,7 @@ import { ConfigCheckerPreferencePickerComponent } from '../config-checker-prefer
 import { HttpClientModule } from '@angular/common/http'
 import { TableModule } from 'primeng/table'
 import { ChipModule } from 'primeng/chip'
-import { OverlayPanelModule } from 'primeng/overlaypanel'
+import { PopoverModule } from 'primeng/popover'
 import { HelpTipComponent } from '../help-tip/help-tip.component'
 import { action } from '@storybook/addon-actions'
 import { ToastModule } from 'primeng/toast'
@@ -22,6 +22,7 @@ import { DataViewModule } from 'primeng/dataview'
 import { ToggleButtonModule } from 'primeng/togglebutton'
 import { FormsModule } from '@angular/forms'
 import { importProvidersFrom } from '@angular/core'
+import { TriStateCheckboxComponent } from '../tri-state-checkbox/tri-state-checkbox.component'
 
 const mockPreferencesData: ConfigCheckers = {
     items: [
@@ -66,11 +67,12 @@ export default {
                 TagModule,
                 TableModule,
                 ChipModule,
-                OverlayPanelModule,
+                PopoverModule,
                 ToastModule,
                 FormsModule,
                 ToggleButtonModule,
                 DataViewModule,
+                TriStateCheckboxComponent,
             ],
             declarations: [
                 ConfigReviewPanelComponent,
