@@ -1,7 +1,7 @@
 import { ComponentFixture, TestBed } from '@angular/core/testing'
 import { By } from '@angular/platform-browser'
 import { NoopAnimationsModule } from '@angular/platform-browser/animations'
-import { OverlayPanelModule } from 'primeng/overlaypanel'
+import { PopoverModule } from 'primeng/popover'
 import { TagModule } from 'primeng/tag'
 import { TooltipModule } from 'primeng/tooltip'
 import { TreeNode } from 'primeng/api'
@@ -13,6 +13,7 @@ import { DividerModule } from 'primeng/divider'
 import { CheckboxModule } from 'primeng/checkbox'
 import { FormsModule } from '@angular/forms'
 import { IPType } from '../iptype'
+import { ButtonModule } from 'primeng/button'
 
 describe('DhcpOptionSetViewComponent', () => {
     let component: DhcpOptionSetViewComponent
@@ -25,10 +26,11 @@ describe('DhcpOptionSetViewComponent', () => {
                 DividerModule,
                 FormsModule,
                 NoopAnimationsModule,
-                OverlayPanelModule,
+                PopoverModule,
                 TagModule,
                 TooltipModule,
                 TreeModule,
+                ButtonModule,
             ],
             declarations: [DhcpOptionSetViewComponent, HelpTipComponent],
         }).compileComponents()
@@ -404,7 +406,7 @@ describe('DhcpOptionSetViewComponent', () => {
         expect(component.getLevelTagSeverity(node)).toBe('success')
 
         node.data.level = 'shared network'
-        expect(component.getLevelTagSeverity(node)).toBe('warning')
+        expect(component.getLevelTagSeverity(node)).toBe('warn')
 
         node.data.level = 'global'
         expect(component.getLevelTagSeverity(node)).toBe('danger')
