@@ -1,11 +1,12 @@
 import { provideHttpClientTesting } from '@angular/common/http/testing'
 import { ComponentFixture, TestBed, waitForAsync } from '@angular/core/testing'
 import { ActivatedRoute, RouterModule } from '@angular/router'
-import { MessageService } from 'primeng/api'
+import { MessageService, ConfirmationService, Confirmation } from 'primeng/api'
 import { ButtonModule } from 'primeng/button'
 import { PaginatorModule } from 'primeng/paginator'
 import { TableModule } from 'primeng/table'
 import { ToastModule } from 'primeng/toast'
+import { ConfirmDialogModule } from 'primeng/confirmdialog'
 
 import { EventsService, ServicesService, UsersService } from '../backend'
 import { EventTextComponent } from '../event-text/event-text.component'
@@ -37,16 +38,19 @@ describe('EventsPanelComponent', () => {
     let component: EventsPanelComponent
     let fixture: ComponentFixture<EventsPanelComponent>
     let sseService: ServerSentEventsService
+    let eventsApi: EventsService
+    let confirmationService: ConfirmationService
 
     beforeEach(waitForAsync(() => {
         TestBed.configureTestingModule({
             declarations: [EventsPanelComponent, LocaltimePipe, EventTextComponent],
-            imports: [PaginatorModule, RouterModule, TableModule, ToastModule, ButtonModule],
+            imports: [PaginatorModule, RouterModule, TableModule, ToastModule, ButtonModule, ConfirmDialogModule],
             providers: [
                 EventsService,
                 UsersService,
                 ServicesService,
                 MessageService,
+                ConfirmationService,
                 {
                     provide: ActivatedRoute,
                     useValue: {},
@@ -63,6 +67,8 @@ describe('EventsPanelComponent', () => {
         component = fixture.componentInstance
         fixture.detectChanges()
         sseService = fixture.debugElement.injector.get(ServerSentEventsService)
+        eventsApi = fixture.debugElement.injector.get(EventsService)
+        confirmationService = fixture.debugElement.injector.get(ConfirmationService)
     })
 
     it('should create', () => {
@@ -183,4 +189,28 @@ describe('EventsPanelComponent', () => {
         component.onToggleExpandEventDetails(42)
         expect(component.expandedEvents.has(42)).toBeFalse()
     })
+
+    it('should remove the events on onClear', () => {
+        spyOn(eventsApi, 'deleteEvents')
+        const confirmSpy = spyOn(confirmationService, 'confirm')
+        // 1. Confirm that the onClear function clears events when the user clicks
+        // the clear button and accepts the confirmation dialog.
+        confirmSpy.and.callFake((confirmation: Confirmation) => {
+            return confirmation.accept()
+        })
+        component.onClear()
+        expect(eventsApi.deleteEvents).toHaveBeenCalledTimes(1)
+
+        // 2. Confirm that the onClear function doesn't clear events when the user
+        // clicks the clear button and then *rejects* the confirmation dialog.
+        confirmSpy.and.callFake((confirmation: Confirmation) => {
+            if (confirmation.reject) {
+                return confirmation.reject()
+            }
+        })
+        component.onClear()
+        // deleteEvents should still have been called one time (i.e. *not* called
+        // a second time).
+        expect(eventsApi.deleteEvents).toHaveBeenCalledTimes(1)
+    })
 })
