@@ -15,6 +15,7 @@ import { ServerSentEventsService } from '../server-sent-events.service'
  */
 @Component({
     selector: 'app-events-panel',
+    standalone: false,
     templateUrl: './events-panel.component.html',
     styleUrls: ['./events-panel.component.sass'],
     providers: [ConfirmationService],
@@ -368,6 +369,7 @@ export class EventsPanelComponent implements OnInit, OnChanges, OnDestroy {
             acceptLabel: 'Clear',
             rejectLabel: 'Cancel',
             defaultFocus: 'none',
+            rejectButtonProps: { text: true, icon: 'pi pi-times' },
             accept: () => {
                 this.loading = true
                 lastValueFrom(this.eventsApi.deleteEvents())
