@@ -1,7 +1,8 @@
 import { ComponentFixture, TestBed, waitForAsync } from '@angular/core/testing'
 
 import { ForbiddenPageComponent } from './forbidden-page.component'
-import { MessagesModule } from 'primeng/messages'
+import { MessageModule } from 'primeng/message'
+import { NoopAnimationsModule } from '@angular/platform-browser/animations'
 
 describe('ForbiddenPageComponent', () => {
     let component: ForbiddenPageComponent
@@ -9,7 +10,7 @@ describe('ForbiddenPageComponent', () => {
 
     beforeEach(waitForAsync(() => {
         TestBed.configureTestingModule({
-            imports: [MessagesModule],
+            imports: [MessageModule, NoopAnimationsModule],
             declarations: [ForbiddenPageComponent],
         }).compileComponents()
     }))
