@@ -1,7 +1,8 @@
 import { ComponentFixture, TestBed, waitForAsync } from '@angular/core/testing'
 
 import { HelpTipComponent } from './help-tip.component'
-import { OverlayPanelModule } from 'primeng/overlaypanel'
+import { PopoverModule } from 'primeng/popover'
+import { ButtonModule } from 'primeng/button'
 
 describe('HelpTipComponent', () => {
     let component: HelpTipComponent
@@ -9,7 +10,7 @@ describe('HelpTipComponent', () => {
 
     beforeEach(waitForAsync(() => {
         TestBed.configureTestingModule({
-            imports: [OverlayPanelModule],
+            imports: [PopoverModule, ButtonModule],
             declarations: [HelpTipComponent],
         }).compileComponents()
     }))
