@@ -1,6 +1,6 @@
 import { Component, Input, ViewChild } from '@angular/core'
 
-import { OverlayPanel } from 'primeng/overlaypanel'
+import { Popover } from 'primeng/popover'
 
 /**
  * Component displaying help box for widgets.
@@ -10,15 +10,18 @@ import { OverlayPanel } from 'primeng/overlaypanel'
  */
 @Component({
     selector: 'app-help-tip',
+    standalone: false,
     templateUrl: './help-tip.component.html',
     styleUrls: ['./help-tip.component.sass'],
 })
 export class HelpTipComponent {
-    @ViewChild(OverlayPanel)
-    overlay: OverlayPanel
+    /**
+     * View child Popover component.
+     */
+    @ViewChild('po') popover: Popover
 
     /**
-     * Target component to align the overlay of the help-tip.
+     * Target component to align the popover of the help-tip.
      */
     @Input() target: any
 
@@ -37,10 +40,27 @@ export class HelpTipComponent {
      */
     @Input() variant: 'big' | '' = ''
 
+    /**
+     * Custom button style.
+     */
+    helpTipButton = {
+        root: {
+            lgFontSize: '2rem',
+        },
+        colorScheme: {
+            dark: {
+                root: {
+                    textPrimaryColor: '{primary.300}',
+                    textPrimaryHoverBackground: '{primary.900}',
+                },
+            },
+        },
+    }
+
     constructor() {}
 
     /** Show/hide the help tip content. */
-    toggleOverlay(ev) {
-        this.overlay.toggle(ev, this.target)
+    togglePopover(ev) {
+        this.popover.toggle(ev, this.target)
     }
 }
