@@ -7,13 +7,13 @@ import { of, throwError } from 'rxjs'
 import { MessageService } from 'primeng/api'
 import { ButtonModule } from 'primeng/button'
 import { CheckboxModule } from 'primeng/checkbox'
-import { DropdownModule } from 'primeng/dropdown'
+import { SelectModule } from 'primeng/select'
 import { FieldsetModule } from 'primeng/fieldset'
 import { InputNumberModule } from 'primeng/inputnumber'
-import { InputSwitchModule } from 'primeng/inputswitch'
-import { MessagesModule } from 'primeng/messages'
+import { ToggleSwitchModule } from 'primeng/toggleswitch'
+import { MessageModule } from 'primeng/message'
 import { MultiSelectModule } from 'primeng/multiselect'
-import { OverlayPanelModule } from 'primeng/overlaypanel'
+import { PopoverModule } from 'primeng/popover'
 import { HostFormComponent } from './host-form.component'
 import { ToggleButtonModule } from 'primeng/togglebutton'
 import { SplitButtonModule } from 'primeng/splitbutton'
@@ -136,15 +136,15 @@ describe('HostFormComponent', () => {
                 ButtonModule,
                 CheckboxModule,
                 AutoCompleteModule,
-                DropdownModule,
+                SelectModule,
                 FieldsetModule,
                 FormsModule,
                 InputNumberModule,
-                InputSwitchModule,
-                MessagesModule,
+                ToggleSwitchModule,
+                MessageModule,
                 MultiSelectModule,
                 NoopAnimationsModule,
-                OverlayPanelModule,
+                PopoverModule,
                 ReactiveFormsModule,
                 RouterModule,
                 SplitButtonModule,
@@ -182,7 +182,7 @@ describe('HostFormComponent', () => {
         tick()
         expect(component.form).toBeTruthy()
         expect(component.form.preserved).toBeFalse()
-        expect(component.form.transactionId).toBe(123)
+        expect(component.form.transactionID).toBe(123)
         expect(component.form.group).toBeTruthy()
         expect(component.form.allSubnets.length).toBe(4)
         expect(component.form.filteredSubnets.length).toBe(4)
@@ -766,7 +766,7 @@ describe('HostFormComponent', () => {
 
         expect(component.form.initError).toEqual('status: 404')
 
-        const messagesElement = fixture.debugElement.query(By.css('p-messages'))
+        const messagesElement = fixture.debugElement.query(By.css('p-message'))
         expect(messagesElement).toBeTruthy()
         expect(messagesElement.nativeElement.outerText).toContain(component.form.initError)
 
@@ -778,7 +778,7 @@ describe('HostFormComponent', () => {
         tick()
         fixture.detectChanges()
 
-        expect(fixture.debugElement.query(By.css('p-messages'))).toBeFalsy()
+        expect(fixture.debugElement.query(By.css('p-message'))).toBeFalsy()
         expect(fixture.debugElement.query(By.css('[label="Retry"]'))).toBeFalsy()
         expect(fixture.debugElement.query(By.css('[label="Submit"]'))).toBeTruthy()
     }))
@@ -860,7 +860,7 @@ describe('HostFormComponent', () => {
                 },
             ],
         }
-        expect(dhcpApi.createHostSubmit).toHaveBeenCalledWith(component.form.transactionId, host)
+        expect(dhcpApi.createHostSubmit).toHaveBeenCalledWith(component.form.transactionID, host)
         expect(component.formSubmit.emit).toHaveBeenCalled()
         expect(messageService.add).toHaveBeenCalled()
     }))
@@ -908,7 +908,7 @@ describe('HostFormComponent', () => {
                 },
             ],
         }
-        expect(dhcpApi.createHostSubmit).toHaveBeenCalledWith(component.form.transactionId, host)
+        expect(dhcpApi.createHostSubmit).toHaveBeenCalledWith(component.form.transactionID, host)
         expect(component.formSubmit.emit).toHaveBeenCalled()
         expect(messageService.add).toHaveBeenCalled()
     }))
@@ -976,7 +976,7 @@ describe('HostFormComponent', () => {
                 },
             ],
         }
-        expect(dhcpApi.createHostSubmit).toHaveBeenCalledWith(component.form.transactionId, host)
+        expect(dhcpApi.createHostSubmit).toHaveBeenCalledWith(component.form.transactionID, host)
         expect(component.formSubmit.emit).toHaveBeenCalled()
         expect(messageService.add).toHaveBeenCalled()
     }))
@@ -1028,7 +1028,7 @@ describe('HostFormComponent', () => {
                 },
             ],
         }
-        expect(dhcpApi.createHostSubmit).toHaveBeenCalledWith(component.form.transactionId, host)
+        expect(dhcpApi.createHostSubmit).toHaveBeenCalledWith(component.form.transactionID, host)
         expect(component.formSubmit.emit).toHaveBeenCalled()
         expect(messageService.add).toHaveBeenCalled()
     }))
@@ -1152,7 +1152,7 @@ describe('HostFormComponent', () => {
                 },
             ],
         }
-        expect(dhcpApi.createHostSubmit).toHaveBeenCalledWith(component.form.transactionId, host)
+        expect(dhcpApi.createHostSubmit).toHaveBeenCalledWith(component.form.transactionID, host)
         expect(component.formSubmit.emit).toHaveBeenCalled()
         expect(messageService.add).toHaveBeenCalled()
 
@@ -1653,7 +1653,7 @@ describe('HostFormComponent', () => {
                 },
             ],
         }
-        expect(dhcpApi.updateHostSubmit).toHaveBeenCalledWith(component.hostId, component.form.transactionId, host)
+        expect(dhcpApi.updateHostSubmit).toHaveBeenCalledWith(component.hostId, component.form.transactionID, host)
         expect(component.formSubmit.emit).toHaveBeenCalled()
         expect(messageService.add).toHaveBeenCalled()
     }))
