@@ -49,6 +49,7 @@ interface LeaseInfo {
  */
 @Component({
     selector: 'app-host-tab',
+    standalone: false,
     templateUrl: './host-tab.component.html',
     styleUrls: ['./host-tab.component.sass'],
 })
@@ -103,7 +104,7 @@ export class HostTabComponent {
     /**
      * Leases fetched for currently selected tab (host).
      */
-    currentLeases: Map<string, LeaseInfo>
+    currentLeases: Map<string, LeaseInfo> = new Map<string, LeaseInfo>()
 
     /**
      * A map of booleans indicating for which hosts leases search
@@ -129,6 +130,7 @@ export class HostTabComponent {
      *
      * @param msgService service displaying error messages upon a communication
      *                   error with the server.
+     * @param confirmService PrimeNG confirmation service
      * @param dhcpApi service used to communicate with the server over REST API.
      */
     constructor(
@@ -543,20 +545,27 @@ export class HostTabComponent {
      * Event handler called when user begins host editing.
      *
      * It emits an event to the parent component to notify that host is
-     * is now edited.
+     * now edited.
      */
-    onHostEditBegin(): void {
+    onEditHostClicked(): void {
         this.hostEditBegin.emit(this.host)
     }
 
-    /*
+    /**
      * Displays a dialog to confirm host deletion.
+     * @param id host ID
      */
-    confirmDeleteHost() {
+    confirmDeleteHost(id: string) {
         this.confirmService.confirm({
+            key: id,
             message: 'Are you sure that you want to permanently delete this host reservation?',
             header: 'Delete Host',
             icon: 'pi pi-exclamation-triangle',
+            rejectButtonProps: { text: true, icon: 'pi pi-times', label: 'Cancel' },
+            acceptButtonProps: {
+                icon: 'pi pi-check',
+                label: 'Delete',
+            },
             accept: () => {
                 this.deleteHost()
             },
