@@ -12,12 +12,12 @@ import {
 } from '../backend'
 import { of, throwError } from 'rxjs'
 import { FieldsetModule } from 'primeng/fieldset'
-import { MessagesModule } from 'primeng/messages'
+import { MessageModule } from 'primeng/message'
 import { NoopAnimationsModule } from '@angular/platform-browser/animations'
 import { SharedParametersFormComponent } from '../shared-parameters-form/shared-parameters-form.component'
 import { ReactiveFormsModule } from '@angular/forms'
 import { CheckboxModule } from 'primeng/checkbox'
-import { DropdownModule } from 'primeng/dropdown'
+import { SelectModule } from 'primeng/select'
 import { InputNumberModule } from 'primeng/inputnumber'
 import { ArrayValueSetFormComponent } from '../array-value-set-form/array-value-set-form.component'
 import { AutoCompleteModule } from 'primeng/autocomplete'
@@ -28,6 +28,7 @@ import { DhcpOptionFormComponent } from '../dhcp-option-form/dhcp-option-form.co
 import { SplitButtonModule } from 'primeng/splitbutton'
 import { provideHttpClient, withInterceptorsFromDi } from '@angular/common/http'
 import { FloatLabelModule } from 'primeng/floatlabel'
+import { TriStateCheckboxComponent } from '../tri-state-checkbox/tri-state-checkbox.component'
 
 describe('KeaGlobalConfigurationFormComponent', () => {
     let component: KeaGlobalConfigurationFormComponent
@@ -250,16 +251,17 @@ describe('KeaGlobalConfigurationFormComponent', () => {
                 ButtonModule,
                 CheckboxModule,
                 AutoCompleteModule,
-                DropdownModule,
+                SelectModule,
                 FieldsetModule,
                 InputNumberModule,
-                MessagesModule,
+                MessageModule,
                 MultiSelectModule,
                 NoopAnimationsModule,
                 ProgressSpinnerModule,
                 ReactiveFormsModule,
                 SplitButtonModule,
                 FloatLabelModule,
+                TriStateCheckboxComponent,
             ],
             providers: [MessageService, provideHttpClient(withInterceptorsFromDi()), provideHttpClientTesting()],
         }).compileComponents()
@@ -414,9 +416,9 @@ describe('KeaGlobalConfigurationFormComponent', () => {
 
         expect(component.initError).toEqual('status: 404')
 
-        const messagesElement = fixture.debugElement.query(By.css('p-messages'))
-        expect(messagesElement).toBeTruthy()
-        expect(messagesElement.nativeElement.outerText).toContain(component.initError)
+        const messageElement = fixture.debugElement.query(By.css('p-message'))
+        expect(messageElement).toBeTruthy()
+        expect(messageElement.nativeElement.outerText).toContain(component.initError)
 
         const retryButton = fixture.debugElement.query(By.css('[label="Retry"]'))
         expect(retryButton).toBeTruthy()
@@ -427,7 +429,7 @@ describe('KeaGlobalConfigurationFormComponent', () => {
         fixture.detectChanges()
         tick()
 
-        expect(fixture.debugElement.query(By.css('p-messages'))).toBeFalsy()
+        expect(fixture.debugElement.query(By.css('p-message'))).toBeFalsy()
         expect(fixture.debugElement.query(By.css('[label="Retry"]'))).toBeFalsy()
         expect(fixture.debugElement.query(By.css('[label="Submit"]'))).toBeTruthy()
     }))
