@@ -9,7 +9,7 @@ import {
     ViewContainerRef,
 } from '@angular/core'
 import { AccessType, AuthService, ManagedAccessEntity } from './auth.service'
-import { Messages } from 'primeng/messages'
+import { Message } from 'primeng/message'
 
 /**
  * This directive is meant to check authorization privileges for given entity.
@@ -70,44 +70,23 @@ export class ManagedAccessDirective implements AfterViewInit {
                 return
             }
 
-            // If this is a PrimeNG element...
-            if (this.htmlElement.classList.contains('p-element')) {
-                this.setDisabledClasses(this.htmlElement)
-
-                // If this is a <button> element with PrimeNG pButton directive applied...
-                if (this.htmlElement.nodeName.toUpperCase() === 'BUTTON') {
-                    this.setDisabledAttributes(this.htmlElement)
-                    return
-                }
-
-                // This is other PrimeNG element, e.g. <p-button>, <p-tristatecheckbox>, <p-inputswitch>, etc.
-                this.htmlElement.querySelectorAll('.p-component').forEach((el) => {
-                    // For all elements inside with .p-component class add disabled classes.
-                    this.setDisabledClasses(<HTMLElement>el)
-                })
-                this.htmlElement.querySelectorAll('input,button').forEach((el) => {
-                    // Set attributes and classes for all input and button elements found inside.
+            // If this is a PrimeNG component...
+            const pComponent = this.htmlElement.querySelector('.p-component')
+            if (pComponent) {
+                this.htmlElement.querySelectorAll('.p-component,input,button').forEach((el) => {
+                    // Set attributes and classes for all input and button elements or elements with .p-component class.
                     this.setDisabledAttributes(<HTMLElement>el)
                     this.setDisabledClasses(<HTMLElement>el)
                 })
-
-                // p-tristatecheckbox has .p-checkbox inside which requires additional class.
-                this.htmlElement.querySelector('.p-checkbox')?.classList.add('p-checkbox-disabled')
                 return
             }
 
-            const messages = this.viewRef.createComponent(Messages)
-            messages.instance.severity = 'warn'
-            messages.instance.closable = false
-            messages.instance.value = [
-                {
-                    severity: 'warn',
-                    summary: 'Access Denied',
-                    detail: `You don\'t have ${this.appAccessType} privileges to display this UI component.`,
-                    closable: false,
-                },
-            ]
-            this.htmlElement.replaceChildren(messages.instance.el.nativeElement)
+            const message = this.viewRef.createComponent(Message)
+            message.instance.severity = 'warn'
+            message.instance.closable = false
+            message.instance.escape = false
+            message.instance.text = `<span><b>Access Denied!</b><br>You don't have ${this.appAccessType} privileges to display this UI component.</span>`
+            this.htmlElement.replaceChildren(message.instance.el.nativeElement)
         }
     }
 
@@ -126,6 +105,7 @@ export class ManagedAccessDirective implements AfterViewInit {
      */
     private setDisabledAttributes(el: HTMLElement): void {
         this.renderer.setAttribute(el, 'disabled', 'disabled')
+        this.renderer.setAttribute(el, 'data-p-disabled', 'true')
         this.renderer.setAttribute(el, 'title', this._title)
     }
 
