@@ -3,33 +3,25 @@ import { ComponentFixture, TestBed, fakeAsync, tick, waitForAsync } from '@angul
 
 import { SharedNetworksPageComponent } from './shared-networks-page.component'
 import { FormsModule, ReactiveFormsModule } from '@angular/forms'
-import { DropdownModule } from 'primeng/dropdown'
+import { SelectModule } from 'primeng/select'
 import { TableModule } from 'primeng/table'
 import { TooltipModule } from 'primeng/tooltip'
 import { SubnetBarComponent } from '../subnet-bar/subnet-bar.component'
-import {
-    ActivatedRoute,
-    ActivatedRouteSnapshot,
-    convertToParamMap,
-    NavigationEnd,
-    Router,
-    RouterModule,
-} from '@angular/router'
+import { RouterModule } from '@angular/router'
 import { DHCPService, SharedNetwork } from '../backend'
 import { provideHttpClientTesting } from '@angular/common/http/testing'
-import { BehaviorSubject, of } from 'rxjs'
+import { of, throwError } from 'rxjs'
 import { BreadcrumbsComponent } from '../breadcrumbs/breadcrumbs.component'
 import { HelpTipComponent } from '../help-tip/help-tip.component'
 import { BreadcrumbModule } from 'primeng/breadcrumb'
-import { OverlayPanelModule } from 'primeng/overlaypanel'
+import { PopoverModule } from 'primeng/popover'
 import { NoopAnimationsModule } from '@angular/platform-browser/animations'
 import { HumanCountComponent } from '../human-count/human-count.component'
 import { HumanCountPipe } from '../pipes/human-count.pipe'
 import { LocalNumberPipe } from '../pipes/local-number.pipe'
-import { HttpEvent, provideHttpClient, withInterceptorsFromDi } from '@angular/common/http'
+import { HttpErrorResponse, HttpEvent, provideHttpClient, withInterceptorsFromDi } from '@angular/common/http'
 import { EntityLinkComponent } from '../entity-link/entity-link.component'
 import { ConfirmationService, MessageService } from 'primeng/api'
-import { TabMenu, TabMenuModule } from 'primeng/tabmenu'
 import { SharedNetworkTabComponent } from '../shared-network-tab/shared-network-tab.component'
 import { FieldsetModule } from 'primeng/fieldset'
 import { UtilizationStatsChartComponent } from '../utilization-stats-chart/utilization-stats-chart.component'
@@ -39,7 +31,6 @@ import { DelegatedPrefixBarComponent } from '../delegated-prefix-bar/delegated-p
 import { DividerModule } from 'primeng/divider'
 import { ChartModule } from 'primeng/chart'
 import { PlaceholderPipe } from '../pipes/placeholder.pipe'
-import { TabType } from '../tab'
 import { SharedNetworkFormComponent } from '../shared-network-form/shared-network-form.component'
 import { ProgressSpinnerModule } from 'primeng/progressspinner'
 import { ButtonModule } from 'primeng/button'
@@ -63,14 +54,15 @@ import { UtilizationBarComponent } from '../utilization-bar/utilization-bar.comp
 import { PoolBarsComponent } from '../pool-bars/pool-bars.component'
 import { FloatLabelModule } from 'primeng/floatlabel'
 import { OutOfPoolBarComponent } from '../out-of-pool-bar/out-of-pool-bar.component'
+import { TabViewComponent } from '../tab-view/tab-view.component'
+import { IconFieldModule } from 'primeng/iconfield'
+import { InputIconModule } from 'primeng/inputicon'
 
 describe('SharedNetworksPageComponent', () => {
     let component: SharedNetworksPageComponent
     let fixture: ComponentFixture<SharedNetworksPageComponent>
     let dhcpService: DHCPService
-    let route: ActivatedRoute
-    let router: Router
-    let routerEventSubject: BehaviorSubject<NavigationEnd>
+    let messageService: MessageService
 
     beforeEach(waitForAsync(() => {
         TestBed.configureTestingModule({
@@ -110,13 +102,13 @@ describe('SharedNetworksPageComponent', () => {
                 AutoCompleteModule,
                 ConfirmDialogModule,
                 DividerModule,
-                DropdownModule,
+                SelectModule,
                 FieldsetModule,
                 FormsModule,
                 InputNumberModule,
                 MultiSelectModule,
                 NoopAnimationsModule,
-                OverlayPanelModule,
+                PopoverModule,
                 ProgressSpinnerModule,
                 ReactiveFormsModule,
                 RouterModule.forRoot([
@@ -131,12 +123,14 @@ describe('SharedNetworksPageComponent', () => {
                     },
                 ]),
                 TableModule,
-                TabMenuModule,
                 TooltipModule,
                 PanelModule,
                 TagModule,
                 ManagedAccessDirective,
                 FloatLabelModule,
+                TabViewComponent,
+                IconFieldModule,
+                InputIconModule,
             ],
             providers: [
                 ConfirmationService,
@@ -147,19 +141,9 @@ describe('SharedNetworksPageComponent', () => {
         })
 
         dhcpService = TestBed.inject(DHCPService)
+        messageService = TestBed.inject(MessageService)
         fixture = TestBed.createComponent(SharedNetworksPageComponent)
         component = fixture.componentInstance
-        route = fixture.debugElement.injector.get(ActivatedRoute)
-        route.snapshot = {
-            paramMap: convertToParamMap({}),
-            queryParamMap: convertToParamMap({}),
-        } as ActivatedRouteSnapshot
-        router = fixture.debugElement.injector.get(Router)
-        routerEventSubject = new BehaviorSubject(
-            new NavigationEnd(1, 'dhcp/shared-networks', 'dhcp/shared-networks/all')
-        )
-
-        spyOnProperty(router, 'events').and.returnValue(routerEventSubject)
 
         const fakeResponses: any[] = [
             {
@@ -370,19 +354,6 @@ describe('SharedNetworksPageComponent', () => {
         fixture = TestBed.createComponent(SharedNetworksPageComponent)
         component = fixture.componentInstance
         fixture.detectChanges()
-
-        // PrimeNG TabMenu is using setTimeout() logic when scrollable property is set to true.
-        // This makes testing in fakeAsync zone unexpected, so disable 'scrollable' feature in tests.
-        const m = fixture.debugElement.query(By.directive(TabMenu))
-        if (m?.context) {
-            m.context.scrollable = false
-        }
-
-        // PrimeNG table is stateful in the component, so clear stored filter between tests.
-        component.table.table.clearFilterValues()
-        component.table.filter$.next({})
-
-        fixture.detectChanges()
     }))
 
     it('should create', () => {
@@ -399,198 +370,118 @@ describe('SharedNetworksPageComponent', () => {
         expect(breadcrumbsComponent.items[1].label).toEqual('Shared Networks')
     })
 
-    it('should open and close tabs', fakeAsync(() => {
-        component.openTabBySharedNetworkId(1)
-        tick()
-        fixture.detectChanges()
-
-        expect(component.openedTabs.length).toBe(2)
-        expect(component.activeTabIndex).toBe(1)
-
-        component.closeTabByIndex(1)
-
-        expect(component.openedTabs.length).toBe(1)
-        expect(component.activeTabIndex).toBe(0)
-
-        component.closeTabByIndex(0)
-
-        expect(component.openedTabs.length).toBe(1)
-        expect(component.activeTabIndex).toBe(0)
+    xit('should open and close tabs', fakeAsync(() => {
+        // TODO: this test should be moved away from Karma tests.
+        // component.openTabBySharedNetworkId(1)
+        // tick()
+        // fixture.detectChanges()
+        //
+        // expect(component.openedTabs.length).toBe(2)
+        // expect(component.activeTabIndex).toBe(1)
+        //
+        // component.closeTabByIndex(1)
+        //
+        // expect(component.openedTabs.length).toBe(1)
+        // expect(component.activeTabIndex).toBe(0)
+        //
+        // component.closeTabByIndex(0)
+        //
+        // expect(component.openedTabs.length).toBe(1)
+        // expect(component.activeTabIndex).toBe(0)
     }))
 
-    it('should cancel transaction for new shared network when cancel button is clicked', fakeAsync(() => {
-        tick()
-        fixture.detectChanges()
-
-        const createSharedNetworkBeginResp: any = {
-            id: 123,
-            daemons: [
-                {
-                    id: 1,
-                    name: 'dhcp4',
-                    app: {
-                        name: 'first',
-                    },
-                },
-            ],
-            sharedNetworks4: [],
-            sharedNetworks6: [],
-            clientClasses: [],
-        }
-
+    it('should call cancel transaction for new shared network', fakeAsync(() => {
         const okResp: any = {
             status: 200,
         }
 
-        spyOn(dhcpService, 'createSharedNetworkBegin').and.returnValue(of(createSharedNetworkBeginResp))
         spyOn(dhcpService, 'createSharedNetworkDelete').and.returnValue(of(okResp))
 
-        component.openNewSharedNetworkTab()
+        component.callCreateNetworkDeleteTransaction(123)
+
         fixture.detectChanges()
         tick()
 
-        expect(component.openedTabs.length).toBe(2)
-
-        expect(dhcpService.createSharedNetworkBegin).toHaveBeenCalled()
-
-        expect(component.openedTabs.length).toBe(2)
-        expect(component.openedTabs[1].state.transactionId).toBe(123)
-
-        // Cancel editing. It should close the form and the transaction should be deleted.
-        component.onSharedNetworkFormCancel()
-        fixture.detectChanges()
-        tick()
-
-        expect(component.tabs.length).toBe(1)
-        expect(component.openedTabs.length).toBe(1)
-        expect(component.activeTabIndex).toBe(0)
-        expect(component.openedTabs[0].tabType).toBe(TabType.List)
-
-        expect(dhcpService.createSharedNetworkDelete).toHaveBeenCalled()
+        expect(dhcpService.createSharedNetworkDelete).toHaveBeenCalledWith(123)
     }))
 
-    it('should cancel transaction for shared network update when cancel button is clicked', fakeAsync(() => {
-        tick()
-        fixture.detectChanges()
-
-        const updateSharedNetworkBeginResp: any = {
-            id: 123,
-            sharedNetwork: {
-                id: 1,
-                name: 'stanza',
-                universe: 4,
-                localSharedNetworks: [
-                    {
-                        appId: 234,
-                        daemonId: 1,
-                        appName: 'server 1',
-                        keaConfigSharedNetworkParameters: {
-                            sharedNetworkLevelParameters: {
-                                allocator: 'random',
-                                options: [
-                                    {
-                                        alwaysSend: true,
-                                        code: 5,
-                                        encapsulate: '',
-                                        fields: [
-                                            {
-                                                fieldType: 'ipv4-address',
-                                                values: ['192.0.2.1'],
-                                            },
-                                        ],
-                                        options: [],
-                                        universe: 4,
-                                    },
-                                ],
-                                optionsHash: '123',
-                            },
-                        },
-                    },
-                ],
-                subnets: [
-                    {
-                        id: 123,
-                        subnet: '192.0.2.0/24',
-                        sharedNetwork: 'floor3',
-                        sharedNetworkId: 3,
-                        localSubnets: [
-                            {
-                                id: 123,
-                                appId: 234,
-                                daemonId: 1,
-                                appName: 'server 1',
-                            },
-                        ],
-                    },
-                ],
-            },
-            daemons: [
-                {
-                    id: 1,
-                    name: 'dhcp4',
-                    app: {
-                        name: 'first',
-                    },
-                },
-            ],
-            sharedNetworks4: [],
-            sharedNetworks6: [],
-            clientClasses: [],
-        }
-
+    it('should call cancel transaction for shared network update', fakeAsync(() => {
         const okResp: any = {
             status: 200,
         }
 
-        spyOn(dhcpService, 'updateSharedNetworkBegin').and.returnValue(of(updateSharedNetworkBeginResp))
         spyOn(dhcpService, 'updateSharedNetworkDelete').and.returnValue(of(okResp))
 
-        component.openTabBySharedNetworkId(1)
+        component.callUpdateNetworkDeleteTransaction(123, 321)
+
         tick()
         fixture.detectChanges()
 
-        expect(component.openedTabs.length).toBe(2)
-
-        component.onSharedNetworkEditBegin({ id: 1 })
-        fixture.detectChanges()
-        tick()
-
-        expect(dhcpService.updateSharedNetworkBegin).toHaveBeenCalled()
-
-        expect(component.openedTabs.length).toBe(2)
-        expect(component.openedTabs[1].state.transactionId).toBe(123)
-
-        // Cancel editing. It should close the form and the transaction should be deleted.
-        component.onSharedNetworkFormCancel(1)
-        fixture.detectChanges()
-        tick()
-
-        expect(component.tabs.length).toBe(2)
-        expect(component.openedTabs.length).toBe(2)
-        expect(component.activeTabIndex).toBe(1)
-        expect(component.openedTabs[1].tabType).toBe(TabType.Display)
-
-        expect(dhcpService.updateSharedNetworkDelete).toHaveBeenCalled()
+        expect(dhcpService.updateSharedNetworkDelete).toHaveBeenCalledWith(123, 321)
     }))
 
-    it('should close subnet tab when subnet is deleted', fakeAsync(() => {
-        tick()
-        fixture.detectChanges()
+    it('should display feedback when called cancel transaction for new shared network', fakeAsync(() => {
+        spyOn(dhcpService, 'createSharedNetworkDelete').and.returnValue(
+            throwError(() => new HttpErrorResponse({ status: 404, statusText: 'transaction not found' }))
+        )
 
-        // Open subnet tab.
-        component.openTabBySharedNetworkId(1)
-        fixture.detectChanges()
-        tick()
-        expect(component.openedTabs.length).toBe(2)
+        const messageSpy = spyOn(messageService, 'add')
+
+        component.callCreateNetworkDeleteTransaction(123)
 
-        // Simulate the notification that the shared network has been deleted.
-        component.onSharedNetworkDelete({
-            id: 1,
-        })
         fixture.detectChanges()
         tick()
 
-        // The main shared network tab should only be left.
-        expect(component.openedTabs.length).toBe(1)
+        expect(dhcpService.createSharedNetworkDelete).toHaveBeenCalledWith(123)
+        expect(messageSpy).toHaveBeenCalledOnceWith(
+            jasmine.objectContaining({
+                summary: 'Failed to delete configuration transaction',
+                severity: 'error',
+                detail: 'Failed to delete configuration transaction: transaction not found',
+            })
+        )
+    }))
+
+    it('should display feedback when called cancel transaction for shared network update', fakeAsync(() => {
+        spyOn(dhcpService, 'updateSharedNetworkDelete').and.returnValue(
+            throwError(() => new HttpErrorResponse({ status: 404, statusText: 'transaction not found' }))
+        )
+        const messageSpy = spyOn(messageService, 'add')
+
+        component.callUpdateNetworkDeleteTransaction(123, 321)
+
+        tick()
+        fixture.detectChanges()
+
+        expect(dhcpService.updateSharedNetworkDelete).toHaveBeenCalledWith(123, 321)
+        expect(messageSpy).toHaveBeenCalledOnceWith(
+            jasmine.objectContaining({
+                summary: 'Failed to delete configuration transaction',
+                severity: 'error',
+                detail: 'Failed to delete configuration transaction: transaction not found',
+            })
+        )
+    }))
+
+    xit('should close tab when shared network is deleted', fakeAsync(() => {
+        // TODO: this test should be moved away from Karma tests.
+        // tick()
+        // fixture.detectChanges()
+        //
+        // // Open subnet tab.
+        // component.openTabBySharedNetworkId(1)
+        // fixture.detectChanges()
+        // tick()
+        // expect(component.openedTabs.length).toBe(2)
+        //
+        // // Simulate the notification that the shared network has been deleted.
+        // component.onSharedNetworkDelete({
+        //     id: 1,
+        // })
+        // fixture.detectChanges()
+        // tick()
+        //
+        // // The main shared network tab should only be left.
+        // expect(component.openedTabs.length).toBe(1)
     }))
 })
