@@ -1,11 +1,10 @@
 import { Component, Input, OnDestroy, OnInit, ViewChild } from '@angular/core'
-import { PrefilteredTable } from '../table'
+import { tableFiltersToQueryParams, tableHasFilter } from '../table'
 import { DHCPService, Subnet } from '../backend'
 import { Table, TableLazyLoadEvent } from 'primeng/table'
-import { ActivatedRoute } from '@angular/router'
-import { MessageService } from 'primeng/api'
-import { Location } from '@angular/common'
-import { lastValueFrom } from 'rxjs'
+import { Router } from '@angular/router'
+import { MessageService, TableState } from 'primeng/api'
+import { debounceTime, lastValueFrom, Subject, Subscription } from 'rxjs'
 import { getErrorMessage, getGrafanaSubnetTooltip, getGrafanaUrl } from '../utils'
 import {
     getTotalAddresses,
@@ -14,66 +13,16 @@ import {
     SubnetWithUniquePools,
     extractUniqueSubnetPools,
 } from '../subnets'
-import { map } from 'rxjs/operators'
-
-/**
- * Specifies the filter parameters for fetching subnets that may be specified
- * either in the URL query parameters or programmatically.
- */
-export interface SubnetsFilter {
-    text?: string
-    appId?: number
-    subnetId?: number
-    dhcpVersion?: 4 | 6
-}
+import { distinctUntilChanged, map } from 'rxjs/operators'
+import { FilterMetadata } from 'primeng/api/filtermetadata'
 
 @Component({
     selector: 'app-subnets-table',
+    standalone: false,
     templateUrl: './subnets-table.component.html',
     styleUrl: './subnets-table.component.sass',
 })
-export class SubnetsTableComponent
-    extends PrefilteredTable<SubnetsFilter, SubnetWithUniquePools>
-    implements OnInit, OnDestroy
-{
-    /**
-     * Array of all numeric keys that are supported when filtering subnets via URL queryParams.
-     * Note that it doesn't have to contain subnets prefilterKey, which is 'appId'.
-     * prefilterKey by default is considered as a primary queryParam filter key.
-     */
-    queryParamNumericKeys: (keyof SubnetsFilter)[] = ['dhcpVersion']
-
-    /**
-     * Array of all boolean keys that are supported when filtering subnets via URL queryParams.
-     */
-    queryParamBooleanKeys: (keyof SubnetsFilter)[] = []
-
-    /**
-     * Array of all numeric keys that can be used to filter subnets.
-     */
-    filterNumericKeys: (keyof SubnetsFilter)[] = ['appId', 'subnetId', 'dhcpVersion']
-
-    /**
-     * Array of all boolean keys that can be used to filter subnets.
-     */
-    filterBooleanKeys: (keyof SubnetsFilter)[] = []
-
-    /**
-     * Prefix of the stateKey. Will be used to evaluate stateKey.
-     */
-    stateKeyPrefix: string = 'subnets-table-session'
-
-    /**
-     * queryParam keyword of the filter by appId.
-     */
-    prefilterKey: keyof SubnetsFilter = 'appId'
-
-    /**
-     * Array of FilterValidators that will be used for validation of filters, which values are limited
-     * only to known values, e.g. dhcpVersion=4|6.
-     */
-    filterValidators = [{ filterKey: 'dhcpVersion', allowedValues: [4, 6] }]
-
+export class SubnetsTableComponent implements OnInit, OnDestroy {
     /**
      * PrimeNG table instance.
      */
@@ -99,14 +48,28 @@ export class SubnetsTableComponent
      */
     @Input() dataLoading: boolean = false
 
+    /**
+     * Collection of subnets currently displayed in the table.
+     */
+    dataCollection: SubnetWithUniquePools[] = []
+
+    /**
+     * Total number of subnets currently displayed in the table.
+     */
+    totalRecords: number = 0
+
+    /**
+     * RxJS Subscription holding all subscriptions to Observables, so that they can be all unsubscribed
+     * at once onDestroy.
+     * @private
+     */
+    private _subscriptions: Subscription = new Subscription()
+
     constructor(
-        route: ActivatedRoute,
         private dhcpApi: DHCPService,
         private messageService: MessageService,
-        location: Location
-    ) {
-        super(route, location)
-    }
+        private router: Router
+    ) {}
 
     /**
      * Loads subnets from the database into the component.
@@ -126,10 +89,10 @@ export class SubnetsTableComponent
                 .getSubnets(
                     event.first,
                     event.rows,
-                    this.prefilterValue ?? this.getTableFilterValue('appId', event.filters),
-                    this.getTableFilterValue('subnetId', event.filters),
-                    this.getTableFilterValue('dhcpVersion', event.filters),
-                    this.getTableFilterValue('text', event.filters)
+                    (event.filters['appId'] as FilterMetadata)?.value ?? null,
+                    (event.filters['subnetId'] as FilterMetadata)?.value ?? null,
+                    (event.filters['dhcpVersion'] as FilterMetadata)?.value ?? null,
+                    (event.filters['text'] as FilterMetadata)?.value || null
                 )
                 // Custom parsing for statistics
                 .pipe(
@@ -161,14 +124,30 @@ export class SubnetsTableComponent
      * Component lifecycle hook called to perform clean-up when destroying the component.
      */
     ngOnDestroy(): void {
-        super.onDestroy()
+        this._tableFilter$.complete()
+        this._subscriptions.unsubscribe()
     }
 
     /**
      * Component lifecycle hook called upon initialization.
      */
     ngOnInit(): void {
-        super.onInit()
+        this._restoreTableRowsPerPage()
+
+        this._subscriptions.add(
+            this._tableFilter$
+                .pipe(
+                    map((f) => ({ ...f, value: f.value === '' ? null : f.value })), // replace empty string filter value with null
+                    debounceTime(300),
+                    distinctUntilChanged()
+                )
+                .subscribe((f) => {
+                    // f.filterConstraint is passed as a reference to PrimeNG table filter FilterMetadata,
+                    // so it's value must be set according to UI columnFilter value.
+                    f.filterConstraint.value = f.value
+                    this.router.navigate([], { queryParams: tableFiltersToQueryParams(this.table) })
+                })
+        )
     }
 
     /**
@@ -273,4 +252,81 @@ export class SubnetsTableComponent
     getGrafanaTooltip(subnet: number, machine: string) {
         return getGrafanaSubnetTooltip(subnet, machine)
     }
+
+    /**
+     * Reference to the function so it can be used in html template.
+     * @protected
+     */
+    protected readonly tableHasFilter = tableHasFilter
+
+    /**
+     * Clears the PrimeNG table state (filtering, pagination are reset).
+     */
+    clearTableState() {
+        this.table?.clear()
+        this.router.navigate([])
+    }
+
+    /**
+     * RxJS Subject used for filtering table data based on UI filtering form inputs (text inputs, checkboxes, dropdowns etc.).
+     * @private
+     */
+    private _tableFilter$ = new Subject<{ value: any; filterConstraint: FilterMetadata }>()
+
+    /**
+     *
+     * @param value
+     * @param filterConstraint
+     * @param debounceMode
+     */
+    filterTable(value: any, filterConstraint: FilterMetadata, debounceMode = true): void {
+        if (debounceMode) {
+            this._tableFilter$.next({ value, filterConstraint })
+            return
+        }
+
+        filterConstraint.value = value
+        this.router.navigate([], { queryParams: tableFiltersToQueryParams(this.table) })
+    }
+
+    /**
+     * Clears single filter of the PrimeNG table.
+     * @param filterConstraint filter metadata to be cleared
+     */
+    clearFilter(filterConstraint: any) {
+        filterConstraint.value = null
+        this.router.navigate([], { queryParams: tableFiltersToQueryParams(this.table) })
+    }
+
+    /**
+     * Keeps number of rows per page in the table.
+     */
+    rows: number = 10
+
+    /**
+     * Key to be used in browser storage for keeping table state.
+     * @private
+     */
+    private readonly _tableStateStorageKey = 'subnets-table-state'
+
+    /**
+     * Stores only rows per page count for the table in user browser storage.
+     */
+    storeTableRowsPerPage(rows: number) {
+        const state: TableState = { rows: rows }
+        const storage = this.table?.getStorage()
+        storage?.setItem(this._tableStateStorageKey, JSON.stringify(state))
+    }
+
+    /**
+     * Restores only rows per page count for the table from the state stored in user browser storage.
+     * @private
+     */
+    private _restoreTableRowsPerPage() {
+        const stateString = localStorage.getItem(this._tableStateStorageKey)
+        if (stateString) {
+            const state: TableState = JSON.parse(stateString)
+            this.rows = state.rows ?? 10
+        }
+    }
 }
