@@ -6,7 +6,7 @@ import { MessageService } from 'primeng/api'
 import { TooltipModule } from 'primeng/tooltip'
 import { Severity, VersionService } from '../version.service'
 import { of } from 'rxjs'
-import { MessagesModule } from 'primeng/messages'
+import { MessageModule } from 'primeng/message'
 import { BrowserAnimationsModule } from '@angular/platform-browser/animations'
 import { provideHttpClient, withInterceptorsFromDi } from '@angular/common/http'
 
@@ -88,7 +88,7 @@ describe('VersionStatusComponent', () => {
     beforeEach(async () => {
         await TestBed.configureTestingModule({
             declarations: [VersionStatusComponent],
-            imports: [TooltipModule, MessagesModule, BrowserAnimationsModule],
+            imports: [TooltipModule, MessageModule, BrowserAnimationsModule],
             providers: [MessageService, provideHttpClient(withInterceptorsFromDi()), provideHttpClientTesting()],
         }).compileComponents()
 
@@ -131,6 +131,11 @@ describe('VersionStatusComponent', () => {
         component.ngOnInit()
         fixture.detectChanges()
         expect(component.appName).toBe('BIND9')
+
+        fixture.componentRef.setInput('app', 'pdns')
+        component.ngOnInit()
+        fixture.detectChanges()
+        expect(component.appName).toBe('PowerDNS')
     })
 
     it('should get current versions data', () => {
@@ -210,7 +215,7 @@ describe('VersionStatusComponent', () => {
         // Arrange
         // Act & Assert
         setCorrectInputs()
-        const messagesDiv = fixture.nativeElement.querySelector('div.p-messages')
+        const messagesDiv = fixture.nativeElement.querySelector('div.p-message')
         expect(messagesDiv).toBeNull()
     })
 
@@ -220,7 +225,7 @@ describe('VersionStatusComponent', () => {
 
         // Act & Assert
         setCorrectInputs()
-        const messagesDiv = fixture.nativeElement.querySelector('div.p-messages')
+        const messagesDiv = fixture.nativeElement.querySelector('div.p-message')
         expect(messagesDiv).toBeTruthy()
     })
 
